# -*- coding:utf-8 -*-
# ROOT_PATH ===========格式是：root + project + FileType + item
import os
import traceback
import platform

sc = os.sep

if platform.platform().startswith("Win"):
    root_path = "C:\\Users\\billsteve\\Desktop\\tmp" + sc
    root_path = "D:\\tmp" + sc
else:
    root_path = "/home/data" + sc

root_path_log = root_path + "logs" + sc
root_path_liebao = root_path + "liebao" + sc
root_path_liebao_log = root_path_liebao + "logs" + sc
root_path_liebao_html = root_path_liebao + "html" + sc
root_path_liebao_cache = root_path_liebao + "cache" + sc
root_path_liebao_json = root_path_liebao_log + "jsons" + sc
root_path_liebao_font = root_path_liebao + "font" + sc
root_path_html = root_path + "html" + sc
root_path_cache = root_path_liebao_cache
EXCEPT_PATH = root_path_liebao_log + "parse_fail.log"
NO_MORE_PATH = root_path_liebao_log + "no_more.log"
NO_DATA_PATH = root_path_liebao_log + "no_data.log"
INCOMPLETE_PATH = root_path_liebao_log + "imcomplete.log"

# car
root_path_car = root_path + "car" + sc
root_path_car_html = root_path_car + "html" + sc
root_path_car_json = root_path_car + "json" + sc
root_path_car_json_car = root_path_car_json + "car" + sc
root_path_car_json_price = root_path_car_json + "price" + sc
root_path_car_json_sale = root_path_car_json + "sale" + sc
root_path_car_json_energy = root_path_car_json + "energy" + sc
root_path_car_html_level = root_path_car_html + "level" + sc

# 12315
root_path_12315 = root_path + "12315" + sc
root_path_12315_log = root_path + "log" + sc

# media
root_path_media = root_path + "media" + sc
root_path_media_html = root_path_media + "html" + sc
root_path_media_json = root_path_media + "json" + sc
root_path_media_log = root_path_media + "log" + sc
root_path_media_html_detail = root_path_media_html + "detail" + sc

# zh
root_path_zh = root_path + "zh" + sc
root_path_zh_cache = root_path_zh + "cache" + sc
root_path_zh_log = root_path_zh + "log" + sc
root_path_zh_json = root_path_zh + "json" + sc
root_path_zh_log_json = root_path_zh_log + "json" + sc

# GOV
root_path_gov = root_path + "gov" + sc
root_path_gov_cache = root_path_gov + "cache" + sc
root_path_gov_log = root_path_gov + "log" + sc
root_path_gov_json = root_path_gov + "json" + sc

# aiweibang
root_path_awb = root_path + "awb" + sc
root_path_awb_cache = root_path_awb + "cache" + sc
root_path_awb_log = root_path_awb + "log" + sc
root_path_awb_json = root_path_awb + "json" + sc

# LOG
Project_log = root_path_zh_log
EXCEPT_PATH = Project_log + "parse_fail.log"
NO_MORE_PATH = Project_log + "no_more.log"
NO_DATA_PATH = Project_log + "no_data.log"
INCOMPLETE_PATH = Project_log + "imcomplete.log"

# _var = vars()
# for k in dir():
#     if k.startswith("root_path"):
#         file_path = _var[k].strip().rstrip(os.sep)
#         isExists = os.path.exists(file_path)
#         if not isExists:
#             try:
#                 os.makedirs(file_path)
#             except:
#                 traceback.print_exc()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time     : 2019/1/4 9:38
# @Email     : billsteve@126.com
# @Des       : SogouCookieModel
# @File        : SogouCookieModel
# @Software: PyCharm
import XX.Model.SqlAlchemy.BaseModel as BM
from sqlalchemy import Column, String
from sqlalchemy.dialects.mysql import INTEGER
from sqlalchemy.ext.declarative import declarative_base

Base = declarative_base()
metadata = Base.metadata


class SogouCookieModel(Base, BM.BaseModel):
    __tablename__ = 'sogou_cookie'

    id = Column(INTEGER(11), primary_key=True)
    cookie = Column(String(64))
    create_ts = Column(INTEGER(11))
    times = Column(INTEGER(11))

    def __init__(self, *arg, **kw):
        self.cookie = kw.get("cookie", None)
        self.create_ts = kw.get("create_ts", None)
        self.id = kw.get("id", None)
        self.metadata = kw.get("metadata", None)
        self.times = kw.get("times", None)


if __name__ == '__main__':
    BM.createInitFunction(SogouCookieModel)



#!/usr/bin/python3
# -*- coding:utf-8 -*-
# @Time        : 2018/7/4 16:09
# @Email       : billsteve@126.com
# @File          : BuiltinFunctions.py
# @Software  : PyCharm
# 重写内部方法
import time

import XX.Date.DatetimeHelper as Dt


def print_function(s, flush=True, *arg, **kw):
    ts = int(kw.get("ts", 0))
    if "ts" in kw:
        kw.pop("ts")
    if "now_ts" in kw:
        kw.pop("now_ts")
    print(s, flush=flush, *arg, **kw)
    time.sleep(ts)


def print_no_end(s, flush=True, end="", *arg, **kw):
    print_function(s, flush=flush, end=end, *arg, **kw)


def print_blank_end(s, flush=True, end=" ", *arg, **kw):
    print_no_end(s, flush=flush, end=end, *arg, **kw)


def print_from_head(s, **kw):
    print_no_end("\r" + Dt.get_now_time(kw.get("now_ts")) + "\t" + str(s), **kw)


def print_wait(ts=1, s="", now_ts=int(time.time())):
    for t in range(ts):
        print_from_head(f"{s} Please Wait {ts - t}" + "." * t + "        ", now_ts=now_ts)
        time.sleep(1)


if __name__ == '__main__':
    print_wait(4, "有延时。")



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time     : 2018/8/14 11:21
# @Author   : Peter
# @Site       : 
# @File        : CarBrands.py
# @Software: PyCharm
from sqlalchemy import Column, Integer, String
from sqlalchemy.ext.declarative import declarative_base

from XX.Model.SqlAlchemy.BaseModel import BaseModel

Base = declarative_base()
metadata = Base.metadata


class CarBrandsModel(Base, BaseModel):
    __tablename__ = 'car_brands'

    id = Column(Integer, primary_key=True)
    brand_id = Column(Integer)
    brands_web_id = Column(Integer, unique=True)
    name = Column(String(255), index=True)
    brandsIsInlet = Column(String(10))
    is_del = Column(Integer)
    create_ts = Column(Integer)
    update_ts = Column(Integer)
    __table_args__ = {
        "mysql_charset": "utf8"
    }

    def __init__(self, *arg, **kw):
        self.brand_id = kw.get("brand_id", None)
        self.brandsIsInlet = kw.get("brandsIsInlet", None)
        self.brands_web_id = kw.get("brands_web_id", None)
        self.create_ts = kw.get("create_ts", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.metadata = kw.get("metadata", None)
        self.name = kw.get("name", None)
        self.update_ts = kw.get("update_ts", None)

    @staticmethod
    def getBrandsByWebId(web_id, session):
        return session.query(CarBrandsModel).filter(CarBrandsModel.brands_web_id == web_id).all()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time     : 2018/9/18 11:00
# @Author   : Peter
# @Des       : 
# @File        : ComModel
# @Software: PyCharm
from XX.Model.SqlAlchemy.BaseModel import *
from sqlalchemy import Column, String, Integer, or_
from sqlalchemy.ext.declarative import declarative_base

Base = declarative_base()
metadata = Base.metadata


class ComModel(Base, BaseModel):
    __tablename__ = 'com'

    id = Column(Integer, primary_key=True)
    regno = Column(String(20), index=True)
    creditno = Column(String(20), index=True)
    other = Column(String(20), index=True)
    is_del = Column(Integer)
    update_ts = Column(Integer)
    create_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.create_ts = kw.get("create_ts", None)
        self.creditno = kw.get("creditno", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.metadata = kw.get("metadata", None)
        self.other = kw.get("other", None)
        self.regno = kw.get("regno", None)
        self.update_ts = kw.get("update_ts", None)

    @staticmethod
    def getByRegcodeOrUccode(regno="", creditno="", other="", session=None):
        return session.query(ComModel).filter(or_(ComModel.regno == regno, ComModel.creditno == creditno, ComModel.other == other)).limit(1).all()


if __name__ == '__main__':
    createInitFunction(ComModel)



# -*- coding:utf-8 -*-
import decimal
import json
from datetime import date,datetime


class DateEncoder(json.JSONEncoder):
    def default(self, obj):
        if isinstance(obj, datetime):
            return obj.strftime('%Y-%m-%d %H:%M:%S')
        elif isinstance(obj, date):
            return obj.strftime("%Y-%m-%d")
        elif isinstance(obj, decimal.Decimal):
            return float(obj)
        if isinstance(obj, bytes):
            return str(obj, encoding='utf-8')
        else:
            return json.JSONEncoder.default(self, obj)



# -*- coding: utf-8 -*-
import base64
import json
import os
import sqlite3

from cryptography.hazmat.primitives.ciphers.aead import AESGCM
from win32crypt import CryptUnprotectData


def get_string(local_state):
    with open(local_state, 'r', encoding='utf-8') as f:
        return json.load(f)['os_crypt']['encrypted_key']


def pull_the_key(base64_encrypted_key):
    encrypted_key_with_header = base64.b64decode(base64_encrypted_key)
    encrypted_key = encrypted_key_with_header[5:]
    key = CryptUnprotectData(encrypted_key, None, None, None, 0)[1]
    return key


def decrypt_string(key, data):
    nonce, cipherbytes = data[3:15], data[15:]
    aesgcm = AESGCM(key)
    plainbytes = aesgcm.decrypt(nonce, cipherbytes, None)
    plaintext = plainbytes.decode('utf-8')
    return plaintext


def get_cookie_from_chrome(host='www.cnvd.org.cn'):
    import sys
    if sys.platform.lower().startswith("win"):
        local_state = os.environ['LOCALAPPDATA'] + r'\Google\Chrome\User Data\Local State'
        cookie_path = os.environ['LOCALAPPDATA'] + r"\Google\Chrome\User Data\Default\Cookies"
    else:
        local_state = r'/root/.config/google-chrome/Default/Local State'
        cookie_path = r"/root/.config/google-chrome/Default/Cookies"

    # TODO:
    # if os.path.exists(cookie_path+".db"):
    #     os.remove(cookie_path+".db")
    #     print("removed",os.path.exists(cookie_path+".db"))
    # copyfile(cookie_path,cookie_path+".db")

    sql = "select host_key,name,encrypted_value from cookies where host_key='%s'" % host
    with sqlite3.connect(cookie_path) as conn:
        cu = conn.cursor()
        res = cu.execute(sql).fetchall()
        cu.close()
        cookies = {}
        key = pull_the_key(get_string(local_state))
        for host_key, name, encrypted_value in res:
            if encrypted_value[0:3] == b'v10':
                cookies[name] = decrypt_string(key, encrypted_value)
            else:
                cookies[name] = CryptUnprotectData(encrypted_value)[1].decode()
        return cookies


if __name__ == '__main__':
    s = get_cookie_from_chrome()
    print(s)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time     : 2018/12/3 13:24
# @Email     : billsteve@126.com
# @Des       : 添加入口URL
# @File        : InitUrl
# @Software: PyCharm
import importlib
import json
import time

from logzero import logger

import XX.BloomFilter as BloomFilter
import XX.BuiltinFunctions as BF
import XX.DB.RedisHelper as ur
import XX.DB.SqlAlchemyHelper as sa
from XX.DB.RedisHelper import RedisHelper


# 添加入口url
class AddInitUrl:

    def __init__(self):
        self.spider = None
        self.url = None
        self.conn_redis = None

    def add(self, **kwargs):
        return self.conn_redis.lpush(self.spider + kwargs.get("suffix", ":start_urls"), self.url)

    # url2redis
    @staticmethod
    def add_url2redis(spider, url, conn_redis, **kwargs):
        return conn_redis.lpush(spider + kwargs.get("suffix", ":start_urls"), url)

    # URL到redis_cfg
    @staticmethod
    def add_url2rediscfg(spider, url, cfg, **kwargs):
        conn_redis = ur.RedisHelper.get_redis_connect_by_cfg(cfg)
        return conn_redis.lpush(spider + kwargs.get("suffix", ":start_urls"), url)

    # 把数据库中的某一列添加到某个队列中，并且值作为url_fun的参数，添加的是返回值
    @staticmethod
    def add_table_column2redis(pro_num, *args, column=None, url_fun=None, process_num=10, fn="", spider="", module_name="",
                               class_name=None, r_cfg=None, m_cfg=None, service=True, from_id=None, limit=3000, **kwargs):
        session = sa.SqlAlchemyHelper.get_session_by_cfg(m_cfg)
        conn_redis = ur.RedisHelper.get_redis_connect_by_cfg(r_cfg)
        if kwargs.get("del_q"):
            conn_redis.delete(spider + kwargs.get("suffix", ":start_urls"))
        if from_id is None:
            from_id = conn_redis.get("kid_" + str(fn) + "_" + class_name + "_" + str(pro_num) + "_from_id")
            from_id = from_id if from_id else 0
            logger.info("From id is \t" + str(from_id))

        while 1:
            if conn_redis.llen(spider + kwargs.get("suffix", ":start_urls")) > limit:
                BF.print_from_head("===Too much\t" + class_name + "\t")
                time.sleep(2 * (pro_num + 1))
                continue
            model_class = getattr(importlib.import_module(module_name), class_name)
            infos = model_class.getByFromIdAndMod(from_id, process_num, pro_num, session, limit=10)
            if infos:
                for info in infos:
                    if url_fun:
                        url = url_fun(info.__dict__.get(column))
                    else:
                        url = info.__dict__.get(column)
                    if url:
                        url = url.strip()
                        if kwargs.get("bf"):
                            bf = BloomFilter.BloomFilter(conn_redis, key=spider)
                            if bf.is_exists(url):
                                BF.print_no_end("-")
                            else:
                                res = conn_redis.lpush(spider + kwargs.get("suffix", ":start_urls"), url)
                                logger.info(str((spider, res, info.id, url)))
                                bf.add(url)
                        else:
                            res = conn_redis.lpush(spider + kwargs.get("suffix", ":start_urls"), url)
                            logger.info(str((spider, res, info.id, url)))

                    from_id = info.id
                    conn_redis.set("kid_" + str(fn) + "_" + class_name + "_" + str(pro_num) + "_from_id", from_id)
            else:
                if service:
                    BF.print_from_head("No More\t" + class_name + "\t")
                    time.sleep(2 * (pro_num + 1))
                    session.commit()
                else:
                    return

    # 文件到队列
    @staticmethod
    def add_file2redis(spider, fp, conn_redis, line_func=None):
        for url in open(fp, encoding="utf-8"):
            if line_func:
                url = line_func(url)
            AddInitUrl.add_url2redis(spider, url, conn_redis)

    # 添加check url
    @staticmethod
    def addCheckUrl(project, url, spider, conn, suffix=":start_urls:check"):
        d = dict()
        d["url"] = url
        d["project"] = project
        d["spider"] = spider
        url = json.dumps(d, ensure_ascii=False)
        return conn.lpush(spider + suffix, url)

    # 把check的URL添加到IU中
    @staticmethod
    def addInitUrlFromCheck(hcfg, redis_cfg, getRow, ts=0):
        import XX.DB.HappyBaseHelper as HaB

        conn_redis = RedisHelper.get_redis_connect_by_cfg(redis_cfg)
        # TODO:
        conn_hbase = HaB.HappyBaseHelper.get_connection_by_cfg(hcfg)
        # pool = HaB.HappyBaseHelper.getPoolByCfg(hcfg)
        while 1:
            keys = conn_redis.keys("*:start_urls:check")
            if not keys:
                BF.print_from_head("No More Check IU in " + str(redis_cfg["host"]), ts=ts)
                continue
            for key in keys:
                jd = json.loads(conn_redis.lpop(key))
                url = jd["url"]
                if url:
                    # table = HaB.HappyBaseHelper.getTable("crawl_" + jd["project"], pool=pool)
                    table = HaB.HappyBaseHelper.get_table("crawl_" + jd["project"], conn=conn_hbase)
                    # HBase是否存在
                    row = getRow(url=url)
                    if row:
                        exists = HaB.HappyBaseHelper.get_row(row)
                        if not exists:
                            res = conn_redis.lpush(key[:-6], url)
                            print("Add new IU res \t\t" + str(res))
                        else:
                            print("Already Crawled!\t\t" + url)
                    else:
                        print("==== No row key", jd)
                time.sleep(ts)

    # 重新添加不是200的url到Check
    @staticmethod
    def readNot200(redis_cfg, ts=10, suffix=":init_urls"):
        conn_redis = RedisHelper.get_redis_connect_by_cfg(redis_cfg)
        while 1:
            keys = conn_redis.keys("*not200*")
            if not keys:
                BF.print_from_head("No More Spider in " + str(redis_cfg["host"]), ts=ts)
                continue
            for key in keys:
                url = conn_redis.spop(key)
                if url:
                    if conn_redis.sadd("s_not_200_urls", url):
                        logger.info("Readd url res is\t" + str(conn_redis.lpush(key.split(":")[0] + suffix, url)) + "\tkey is\t" + key[:-7] + "\t url is \t" + url)
                    else:
                        print("Retry already!")
                else:
                    logger.info("No url in set \t" + str(key))
                time.sleep(ts)



#!/usr/bin/python3
# -*- coding:utf-8 -*-
# @Time       : 2019/2/15 21:04
# @Author    : Bill Steve
# @Email      : billsteve@126.com
# @File         : TestDM.py
# @Des         : 
# @Software : PyCharm


class TestDM(object):
    @classmethod
    def from_crawler(cls, crawler):
        settings = crawler.settings
        cls.settings = settings
        return cls()

    # 读缓存，生成response
    def process_request(self, request, spider):
        print("===" * 44)
        print(self.settings.get("PROJECT_NAME", "crawl"))
        print(self.settings.get("HBASE_ROW_KEY_FUN"))
        self.settings.get("HBASE_ROW_KEY_FUN")()
        print("===" * 44)



# coding: utf-8
from XX.Model.SqlAlchemy.BaseModel import *
from sqlalchemy import Column, String
from sqlalchemy.dialects.mysql import INTEGER
from sqlalchemy.ext.declarative import declarative_base

Base = declarative_base()
metadata = Base.metadata


class Growing(Base, BaseModel):
    __tablename__ = 'growing'

    id = Column(INTEGER(11), primary_key=True)
    kw = Column(String(30))
    name = Column(String(180), unique=True)

    def __init__(self, *arg, **kw):
        self.id = kw.get("id", None)
        self.kw = kw.get("kw", None)
        self.metadata = kw.get("metadata", None)
        self.name = kw.get("name", None)


if __name__ == '__main__':
    createInitFunction(Growing)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time     : 2018/8/16 16:34
# @Author   : Peter
# @Des       : 
# @File        : PostInfo
# @Software: PyCharm

from sqlalchemy import Column, Integer, Float, String
from sqlalchemy.ext.declarative import declarative_base

from XX.Model.SqlAlchemy.BaseModel import BaseModel

Base = declarative_base()
metadata = Base.metadata


class PostInfoModel(Base, BaseModel):
    __tablename__ = 'bbs_post_info'

    id = Column(Integer, primary_key=True)
    post_id = Column(Integer)
    bbs_read_num = Column(Integer)
    bbs_like_num = Column(Integer)
    bbs_comment_num = Column(Integer)
    bbs_forward_num = Column(Integer)
    tendays_weight = Column(Float)
    month_weight = Column(Float)
    total_weight = Column(Float)
    is_del = Column(Integer)
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.id = kw.get("id", None)
        self.post_id = kw.get("post_id", None)
        self.bbs_read_num = kw.get("bbs_read_num", None)
        self.bbs_like_num = kw.get("bbs_like_num", None)
        self.bbs_comment_num = kw.get("bbs_comment_num", None)
        self.bbs_forward_num = kw.get("bbs_forward_num", None)
        self.tendays_weight = kw.get("tendays_weight", None)
        self.month_weight = kw.get("month_weight", None)
        self.total_weight = kw.get("total_weight", None)
        self.is_del = kw.get("is_del", None)
        self.create_ts = kw.get("create_ts", None)
        self.update_ts = kw.get("update_ts", None)


class PostInfosModel(Base, BaseModel):
    __tablename__ = 'bbs_post_infos'

    id = Column(Integer, primary_key=True)
    uuid = Column(String(35))
    post_id = Column(Integer)
    bbs_read_num = Column(Integer)
    bbs_like_num = Column(Integer)
    bbs_comment_num = Column(Integer)
    bbs_forward_num = Column(Integer)
    tendays_weight = Column(Float)
    month_weight = Column(Float)
    total_weight = Column(Float)
    is_del = Column(Integer)
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.id = kw.get("id", None)
        self.uuid = kw.get("uuid", None)
        self.post_id = kw.get("post_id", None)
        self.bbs_read_num = kw.get("bbs_read_num", None)
        self.bbs_like_num = kw.get("bbs_like_num", None)
        self.bbs_comment_num = kw.get("bbs_comment_num", None)
        self.bbs_forward_num = kw.get("bbs_forward_num", None)
        self.tendays_weight = kw.get("tendays_weight", None)
        self.month_weight = kw.get("month_weight", None)
        self.total_weight = kw.get("total_weight", None)
        self.is_del = kw.get("is_del", None)
        self.create_ts = kw.get("create_ts", None)
        self.update_ts = kw.get("update_ts", None)

    @staticmethod
    def getByUuid(uuid, session):
        return session.query(PostInfosModel).filter(PostInfosModel.uuid == uuid).all()



#!/usr/bin/python3
# -*- coding:utf-8 -*-
# @Time       : 2018/10/30 19:27
# @Author    : Bill Steve
# @Email      : billsteve@126.com
# @File         : QcmNewModel.py
# @Software : PyCharm
from XX.Model.SqlAlchemy.BaseModel import *
from sqlalchemy import Column, Integer, String
from sqlalchemy.dialects.mysql.types import TINYINT
from sqlalchemy.ext.declarative import declarative_base

Base = declarative_base()
metadata = Base.metadata


class QcmNewModel(Base, BaseModel):
    __tablename__ = 'qcm_new'

    id = Column(Integer, primary_key=True)
    name = Column(String(120), unique=True)
    crawl_ts = Column(Integer)
    url = Column(String(120))
    is_del = Column(TINYINT(1))
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.crawl_ts = kw.get("crawl_ts", None)
        self.create_ts = kw.get("create_ts", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.metadata = kw.get("metadata", None)
        self.name = kw.get("name", None)
        self.update_ts = kw.get("update_ts", None)
        self.url = kw.get("url", None)

    @staticmethod
    def addQcm(data, session):
        name = data.get("name")
        if name:
            exists = QcmNewModel.getByName(name, session)
        else:
            return 0
        if not exists:
            qcm = QcmNewModel(**data)
            QcmNewModel.addModel(qcm, session)
            return qcm.id
        return exists[0].id


if __name__ == '__main__':
    createInitFunction(QcmNewModel)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time         : 2019/2/18 15:03
# @File           : DMHelper
# @Des           : 
# @Email        : billsteve@126.com
import XX.Encrypt.EncryptHelper as Enc


def add_HBase(spider, url, html, project_name, conn, row=None):
    table = conn.connection.table("crawl_" + project_name)
    row = spider + "_" + Enc.Encrypt.md5(url) if not row else row
    if table.row(row):
        print("==Exists\t" + row)
        return -1
    data = {
        "source:url": str(url),
        "source:html": str(html),
        "source:type": "html",
        "source:size": str(len(html)),
    }
    conn.addRowColumn(row, data, table=table)
    return 1



#!/usr/bin/python3
# -*- coding:utf-8 -*-
# @Time       : 2018/9/23 14:42
# @Author    : Bill Steve
# @Email      : billsteve@126.com
# @File         : PersonModel.py
# @Software : PyCharm

from XX.Model.SqlAlchemy.BaseModel import *
from sqlalchemy import Column, Integer, String
from sqlalchemy.ext.declarative import declarative_base

Base = declarative_base()
metadata = Base.metadata


class PersonModel(Base, BaseModel):
    __tablename__ = 'person'

    id = Column(Integer, primary_key=True)
    web_id = Column(Integer)
    web_key = Column(String(50))
    name = Column(String(50))
    image = Column(String(200))
    is_del = Column(Integer)
    update_ts = Column(Integer)
    create_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.create_ts = kw.get("create_ts", None)
        self.get = kw.get("get", None)
        self.getAll = kw.get("getAll", None)
        self.getAllIds = kw.get("getAllIds", None)
        self.getByFromId = kw.get("getByFromId", None)
        self.getByFromIdAndMod = kw.get("getByFromIdAndMod", None)
        self.getByName = kw.get("getByName", None)
        self.id = kw.get("id", None)
        self.image = kw.get("image", None)
        self.is_del = kw.get("is_del", None)
        self.metadata = kw.get("metadata", None)
        self.name = kw.get("name", None)
        self.web_key = kw.get("web_key", None)
        self.update_ts = kw.get("update_ts", None)
        self.web_id = kw.get("web_id", None)

    @staticmethod
    def savePerson(data, session):
        web_id = data.get("web_id")
        web_key = data.get("web_key")
        if web_id:
            exists = PersonModel.getByKV("web_id", web_id, session)
        elif web_key:
            exists = PersonModel.getByWebKey(web_key, session)
        else:
            return
        if not exists:
            person = PersonModel(**data)
            PersonModel.addModel(person, session)
            return person.id
        return exists[0].id


if __name__ == '__main__':
    createInitFunction(PersonModel)



# coding: utf-8
from XX.Model.SqlAlchemy.BaseModel import *
from sqlalchemy import Column, String
from sqlalchemy.dialects.mysql import INTEGER
from sqlalchemy.ext.declarative import declarative_base

Base = declarative_base()
metadata = Base.metadata


class Img(Base, BaseModel):
    __tablename__ = 'img'

    id = Column(INTEGER(11), primary_key=True)
    web_id = Column(INTEGER(11))
    picture_url = Column(String(255))

    def __init__(self, *arg, **kw):
        self.id = kw.get("id", None)
        self.metadata = kw.get("metadata", None)
        self.picture_url = kw.get("picture_url", None)
        self.web_id = kw.get("web_id", None)


class Title(Base, BaseModel):
    __tablename__ = 'title'

    id = Column(INTEGER(11), primary_key=True)
    web_id = Column(INTEGER(11), unique=True)
    title = Column(String(255))

    def __init__(self, *arg, **kw):
        self.id = kw.get("id", None)
        self.metadata = kw.get("metadata", None)
        self.title = kw.get("title", None)
        self.web_id = kw.get("web_id", None)


if __name__ == '__main__':
    createInitFunction(Img)
    createInitFunction(Title)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time     : 2018/12/12 17:10
# @Email     : billsteve@126.com
# @Des       : 
# @File        : CompanyInverst
# @Software: PyCharm
from XX.Model.SqlAlchemy.BaseModel import *
from sqlalchemy import Column, String
from sqlalchemy.dialects.mysql import INTEGER
from sqlalchemy.ext.declarative import declarative_base

Base = declarative_base()
metadata = Base.metadata


class CompanyInvest(Base, BaseModel):
    __tablename__ = 'company_invest'

    id = Column(INTEGER(11), primary_key=True)
    invest_id = Column(INTEGER(11))
    invest_to_id = Column(INTEGER(11))
    CompanyCode = Column(String(255))
    Percent = Column(String(255))
    PercentTotal = Column(String(255))
    Level = Column(INTEGER(11))
    Org = Column(INTEGER(11))
    ShouldCapi = Column(String(255))
    StockRightNum = Column(String(255))
    DetailCount = Column(INTEGER(11))
    DetailList = Column(String(255))
    ShortStatus = Column(String(255))
    is_del = Column(INTEGER(11))
    create_ts = Column(INTEGER(11))
    update_ts = Column(INTEGER(11))

    def __init__(self, *arg, **kw):
        self.CompanyCode = kw.get("CompanyCode", None)
        self.DetailCount = kw.get("DetailCount", None)
        self.DetailList = kw.get("DetailList", None)
        self.Level = kw.get("Level", None)
        self.Org = kw.get("Org", None)
        self.Percent = kw.get("Percent", None)
        self.PercentTotal = kw.get("PercentTotal", None)
        self.ShortStatus = kw.get("ShortStatus", None)
        self.ShouldCapi = kw.get("ShouldCapi", None)
        self.StockRightNum = kw.get("StockRightNum", None)
        self.create_ts = kw.get("create_ts", None)
        self.id = kw.get("id", None)
        self.invest_id = kw.get("invest_id", None)
        self.invest_to_id = kw.get("invest_to_id", None)
        self.is_del = kw.get("is_del", None)
        self.metadata = kw.get("metadata", None)
        self.update_ts = kw.get("update_ts", None)

    def getInvestRelation(self, invest_id, invest_to_id, session):
        return session.query(CompanyInvest.id).filter(CompanyInvest.invest_id == invest_id, CompanyInvest.invest_to_id == invest_to_id).limit(1).all()


if __name__ == '__main__':
    createInitFunction(CompanyInvest)



# -*- coding: utf-8 -*-
# 从html中提取正文, 文本密度提取算法
# update time: 20161014
import re
import traceback

from lxml import etree
from scrapy import Selector

import XX.funclib as fun


class GetNewsArticle(object):
    def __init__(self, unicode_url='', unicode_html='', *args, **kwargs):
        self.url = unicode_url
        if type(unicode_html) == str:
            self.html = unicode_html
        else:
            self.html = unicode_html
        if self.url is '' or self.html is '':
            raise ValueError('url or html is null ')
        self.article_content = ''

    def __by_xpath(self):
        try:
            tree = etree.HTML(self.html)
        except:
            tree = etree.HTML(self.html.encode("utf-8"))
        # for 腾讯新闻
        if 'qq.com' in self.url:
            for i in tree.xpath('//div[@id="Cnt-Main-Article-QQ"]//p//text()'):
                self.article_content += i

        # for 今日头条新闻
        elif 'toutiao.com' in self.url:
            for i in tree.xpath('//div[@class="article-content"]//text()'):
                self.article_content += i

        # for 新浪新闻
        elif 'sina.com.cn' in self.url:
            for i in tree.xpath('//div[@id="artibody" or @id="articleContent" or @id="j_articleContent"]//p//text()'):
                self.article_content = self.article_content + fun.clean_str_label(i) + '\n'
            if not self.article_content:
                # ??
                for i in tree.xpath('//div[@id="artibody" or @id="articleContent" or @id="j_articleContent"]//p'):
                    self.article_content = self.article_content + fun.clean_str_label(i.xpath("string(.)")) + '\n'

        # for 搜狐新闻
        elif 'sohu.com' in self.url:
            for i in tree.xpath('//div[@id="contentText"]//text()'):
                self.article_content += i

        # for 网易新闻
        elif '163.com' in self.url:
            for i in tree.xpath('//div[@id="endText"]//text()'):
                self.article_content += i

        # for 汽车之家新闻
        elif 'autohome.com.cn' in self.url:
            # ??
            for i in Selector(text=self.html).xpath(
                    '//div[@id="articleContent" or @class="dealertext" or @id="newsbody"]/p').extract():
                self.article_content = self.article_content + fun.clean_str_label(i) + '\n'

        # for 车质网新闻
        elif '12365auto.com' in self.url:
            # ??
            for i in Selector(text=self.html).xpath('//div[@class="show" or @class="sp_new_show"]/p').extract():
                self.article_content = self.article_content + fun.clean_str_label(i) + '\n'

        # for 易车网新闻
        elif 'bitauto.com' in self.url or 'yiche.com' in self.url:
            # ??
            for i in Selector(text=self.html).xpath(
                    '//div[@class="text_box" or @id="openimg_articlecontent"]/p').extract():
                self.article_content = self.article_content + fun.clean_str_label(i) + '\n'

        # for 一点资讯
        elif 'yidianzixun.com' in self.url:
            for i in Selector(text=self.html).xpath('//div[@id="imedia-article" or @class="content-bd"]//p//text()'):
                self.article_content = self.article_content + fun.clean_str_label(i) + '\n'

        # for 太平洋汽车
        elif 'pcauto.com.cn' in self.url:
            # ??
            for i in Selector(text=self.html).xpath('//div[@class="artText clearfix" or @class="artText"]/p').extract():
                self.article_content = self.article_content + fun.clean_str_label(i) + '\n'

        # for 爱卡汽车 newsbody
        elif 'xcar.com.cn' in self.url:
            # ??
            for i in Selector(text=self.html).xpath(
                    '//div[@id="newsbody" or @class="artical_player_wrap"]/p').extract():
                self.article_content = self.article_content + fun.clean_str_label(i) + '\n'

        # for 车讯网
        elif 'chexun.com' in self.url:
            # ??
            for i in Selector(text=self.html).xpath('//div[@class="news-editbox"]/p').extract():
                self.article_content = self.article_content + fun.clean_str_label(i) + '\n'

        # for 买车网
        elif 'maiche.com' in self.url:
            # ??
            for i in Selector(text=self.html).xpath('//div[@class="content-left"]//div[@class="detail"]//p//text()'):
                if i:
                    self.article_content = self.article_content + fun.clean_str_label(str(i)) + '\n'

        # for 凤凰网
        elif 'ifeng.com' in self.url:
            # ??
            for i in Selector(text=self.html).xpath('//div[@class="arl-c-txt"]/p').extract():
                self.article_content = self.article_content + fun.clean_str_label(i) + '\n'
        else:
            self.article_content = ''

        self.article_content = fun.clean_str_label(self.article_content)

        if len(self.article_content) < 2:
            return False
        else:
            return True

    def __run(self):
        if not self.__by_xpath():
            ex = htmltoarticle(html=self.html)
            self.article_content = ex.get_ariticle()

    def get_article(self):
        try:
            self.__run()
        except:
            traceback.print_exc()
            self.article_content = ''

        if len(self.article_content) < 2:
            return ""
        else:
            return self.article_content


class htmltoarticle(object):
    def __init__(self, *args, **kwargs):
        self.html = kwargs.pop('html', '')
        if self.html is '':
            raise ValueError('html is null ')
        self.lines = []
        self.block = []
        self.threshold_value = 172

    # 移除HTML标签
    def __removeLabel(self):
        re_doctype = re.compile(r'(?is)<!DOCTYPE.*?>', re.S)
        self.html = re_doctype.sub('', self.html)

        re_comment = re.compile(r'(?is)<!--.*?-->', re.S)
        self.html = re_comment.sub('', self.html)

        re_javascript = re.compile(r'(?is)<script.*?>.*?</script>', re.S)
        self.html = re_javascript.sub('', self.html)

        re_css = re.compile(r'(?is)<style.*?>.*?</style>', re.S)
        self.html = re_css.sub('', self.html)

        re_special_char = re.compile(r'&.{2,5};|&#.{2,5};', re.S)
        self.html = re_special_char.sub('', self.html)

        re_other_tag = re.compile(r'(?is)<.*?>', re.S)
        self.html = re_other_tag.sub('', self.html)

        re_empty_char = re.compile(r'\\s', re.S)
        self.html = re_empty_char.sub('', self.html)

    # 移除空格
    def __removeSpace(self, target_str):
        return "".join(target_str.split())

    # 按行分割，并移除每行首尾的空格
    def __statistic_line(self):
        for line in self.html.splitlines(False):
            line = self.__removeSpace(line)
            self.lines.append(line)

    # 获取1-blockwidth行中每行有多少字符
    def __statistic_block(self, blockwidth):
        i = 0
        while i < len(self.lines) - blockwidth:
            block_len = 0
            j = 0
            while j < blockwidth:
                block_len += len(self.lines[i + j])
                j += 1
            self.block.append(block_len)
            i += 1

    # 不知道干什么用的
    def __find_Surge(self, start, threshold):
        i = start
        while i < len(self.block):
            if self.block[i] > threshold and self.block[i + 1] > 0 and self.block[i + 2] > 0 and self.block[i + 3] > 0:
                return i
            i += 1
        return -1

    def __find_Dive(self, surgePoint):
        i = surgePoint + 1
        while i < len(self.block):
            if self.block[i] == 0 and self.block[i + 1] == 0:
                return i
            i += 1
        return len(self.block) - 1

    def __run(self):
        start = 0
        end = 0
        article_content = ''
        while True:
            start = self.__find_Surge(end, self.threshold_value)
            if start < 0:
                break
            end = self.__find_Dive(start)
            for i in range(start, end + 1):
                article_content += self.lines[i]
                article_content += '\n'
        return article_content

    def get_ariticle(self):
        self.__removeLabel()
        self.__statistic_line()
        self.__statistic_block(3)
        return self.__run()


if __name__ == '__main__':
    import XX.HTTP.RequestsHelper as creq

    url = "http://www.chexun.com/2018-04-20/105255634.html"
    r = creq.RequestHelper.SendCacheRequest(url)
    if r.status_code == 200:
        ex = GetNewsArticle(unicode_url=url, unicode_html=r.text)
        print(ex.get_article())
        # ex = htmltoarticle(html=r.text)
        # print ex.get_ariticle()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time     : 2018/8/16 16:38
# @Author   : Peter
# @Des       : 
# @File        : Product
# @Software: PyCharm
from XX.Model.SqlAlchemy.BaseModel import BaseModel
from sqlalchemy import Column, Integer, String
from sqlalchemy.ext.declarative import declarative_base

Base = declarative_base()
metadata = Base.metadata


class Product(Base, BaseModel):
    __tablename__ = 'product'

    id = Column(Integer, primary_key=True)
    name = Column(String(128))
    logo = Column(String(255))

    def __init__(self, *arg, **kw):
        self.id = kw.get("id", None)
        self.logo = kw.get("logo", None)
        self.metadata = kw.get("metadata", None)
        self.name = kw.get("name", None)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time     : 2018/8/24 13:44
# @Author   : Peter
# @Des       : 
# @File        : funclib
# @Software: PyCharm
import datetime
import json
import re
import traceback


# !!!废弃的函数,兼容以前的spider，保留此函数
def unicode_to_str(text, encoding=None, errors='strict'):
    """Return the str representation of text in the given encoding. Unlike
    .encode(encoding) this function can be applied directly to a str
    object without the risk of double-decoding problems (which can happen if
    you don't use the default 'ascii' encoding)
    """
    if encoding is None:
        encoding = 'utf-8'
    if isinstance(text, bytes):
        return text.encode(encoding, errors)
    elif isinstance(text, str):
        return text
    else:
        raise TypeError('unicode_to_str must receive a unicode or str object, got %s' % type(text).__name__)


# 内置数据类型转换成 str
def to_str(data):
    if isinstance(data, (int, float, bool)) or data is None:
        return str(data)
    elif isinstance(data, bytes):
        return data.encode('utf-8')
    elif isinstance(data, str):
        return data
    elif isinstance(data, list):
        return __list_to_str(data)
    elif isinstance(data, dict):
        return __dict_to_str(data)
    elif isinstance(data, tuple):
        return __tuple_to_str(data)
    elif isinstance(data, set):
        return __set_to_str(data)
    elif isinstance(data, (datetime.datetime, datetime.date)):
        return __datetime_to_str(data)
    else:
        print('Dont know how to change %s to str!' % str(type(data)))
        return ''


# 字典转换成字符串, 其中的unicode自动转换成str
def __dict_to_str(data_dict):
    line = '{'
    # print data_dict.items()
    for k, v in data_dict.items():
        line += '%s: %s, ' % (k, to_str(v))
    return line.strip(', ') + '}'


# 列表转换成字符串, 其中的unicode自动转换成str
def __list_to_str(data_list):
    line = '['
    for var in data_list:
        line += '%s, ' % to_str(var)
    return line.strip(', ') + ']'


# tuple转换成str, 其中的unicode自动转换成str
def __tuple_to_str(data_tuple):
    return '(' + __list_to_str(list(data_tuple)).strip('[]') + ')'


# set转换成str, 其中的unicode自动转换成str
def __set_to_str(data_set):
    return 'set(' + __list_to_str(list(data_set)) + ')'


def __datetime_to_str(date_time):
    if isinstance(date_time, datetime.date):
        return str(date_time)
    return date_time.strftime('%Y-%m-%d %H:%M:%S %f')


# !!!废弃的函数,兼容以前的spider，保留此函数
def json_to_dict(target_unicode_str):
    try:
        target = target_unicode_str[target_unicode_str.index("{"):]
        return json.loads(target)
    except:
        pass


# json转字典(gbk)
def json_to_dict_gbk(target_gbk_str):
    try:
        return json.loads(__json_to_standard(target_gbk_str), encoding="gbk")
    except:
        pass


# json转字典(utf8)
def json_to_dict_utf8(target_utf8_str):
    try:
        return json.loads(__json_to_standard(target_utf8_str), encoding="utf-8")
    except:
        pass


# 内置函数
def __json_to_standard(target_str):
    target = target_str[target_str.index("{"):]
    target = target[:target.rindex("}") + 1]
    return target


# 取列表中最大数值, 一般页数是从1开始的
def list_max_number(target_list):
    new_list = []
    for i in target_list:
        i_buffer = ''
        for j in i:
            if j.isdigit() == True:
                i_buffer += j
        if i_buffer.isdigit() == True:
            new_list.append(int(i_buffer))
    if new_list:
        return int(max(new_list))
    else:
        return 1


# 清洗字符串中的换行空格和回车
def clean_str_space(target_str):
    return "".join(target_str.split())


# 清洗字符串中的html标签
def clean_str_label(target_str):
    re_flag = re.compile(r'<[^>]*>', re.S)
    result = re_flag.sub('', target_str)
    return result


# 字符串转list
def str_to_list(target_str):
    if isinstance(target_str, str):
        if target_str == '':
            return []
        elif target_str[0] == '[' and target_str[-1] == ']':
            xlist = []
            for i in target_str[1:-1].split(','):
                if i == '' or i == ' ':
                    continue
                xlist.append(i)
            return xlist
        else:
            raise TypeError(
                'String must be have [ and ], got %s' % type(target_str).__name__)
    else:
        raise TypeError('Type must be string, got %s' %
                        type(target_str).__name__)


# 字符串转字典
def str_to_dict(target_str):
    dict = {}
    for i in target_str.split(';'):
        if '=' in i:
            dict[i.split('=')[0]] = i.split('=')[1]
        else:
            continue
    return dict


# 从字符串提取数字
def str_to_digit(target_str):
    try:
        if isinstance(target_str, bytes):
            target_str = to_str(target_str)
        if len(target_str) > 0:
            return int(re.sub("\D", "", target_str))
        else:
            print("no str")
            return None
    except:
        traceback.print_exc()
        return None


# 从字符串中提取时间
def str_to_time(target_timestr):
    try:
        if isinstance(target_timestr, bytes):
            target_timestr = to_str(target_timestr)
        r = re.search(
            u'\d{4}(:|-|\\|/|年)\d{1,2}(:|-|\\|/|月)\d{1,2}(|日) \d{1,2}(:|-|\\|/|时|点)\d{1,2}', target_timestr)
        if r:
            return r.group(0)
        else:
            return None
    except:
        return None


# 日期计算，通过XX小时，分，天，周来计算时间
def str_to_standard_time(target_cntime_str):
    now = datetime.datetime.now()
    # calc计算方式,False 减, True 加
    if isinstance(target_cntime_str, bytes):
        target_cntime_str = to_str(target_cntime_str)

    if '前' in target_cntime_str:
        calc = False
    elif '后' in target_cntime_str:
        calc = True
    else:
        return target_cntime_str

    if '秒' in target_cntime_str:
        if calc:
            stand_time = now + datetime.timedelta(seconds=str_to_digit(target_cntime_str))
        else:
            stand_time = now - datetime.timedelta(seconds=str_to_digit(target_cntime_str))
    elif '分' in target_cntime_str:
        if calc:
            stand_time = now + datetime.timedelta(minutes=str_to_digit(target_cntime_str))
        else:
            stand_time = now - datetime.timedelta(minutes=str_to_digit(target_cntime_str))
    elif '时' in target_cntime_str:
        if calc:
            stand_time = now + datetime.timedelta(hours=str_to_digit(target_cntime_str))
        else:
            stand_time = now - datetime.timedelta(hours=str_to_digit(target_cntime_str))
    elif '天' in target_cntime_str:
        if calc:
            stand_time = now + datetime.timedelta(days=str_to_digit(target_cntime_str))
        else:
            stand_time = now - datetime.timedelta(days=str_to_digit(target_cntime_str))
    elif '周' in target_cntime_str:
        if calc:
            stand_time = now + datetime.timedelta(weeks=str_to_digit(target_cntime_str))
        else:
            stand_time = now - datetime.timedelta(weeks=str_to_digit(target_cntime_str))
    else:
        raise ValueError('target_cntime_str must include 时分秒天周, and so on ')
    return stand_time.strftime('%Y-%m-%d %H:%M:%S')


# 清空字典中空数据
def clean_dict(data_dict):
    if isinstance(data_dict, dict):
        for k, v in data_dict.items():
            if not v == 0 and not v:
                data_dict.pop(k)
            else:
                if '.' in k:
                    data_dict[re.sub('\.', '~', k)] = data_dict.pop(k)
                clean_dict(v)
    elif isinstance(data_dict, list):
        for var in data_dict:
            clean_dict(var)
    return data_dict


if __name__ == "__main__":
    print(str_to_standardtime("2天前"))



# -*- coding: utf-8 -*-
import random


class Header(object):
    headers = {
        "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8",
        "Accept-Encoding": "gzip, deflate, br",
        "Accept-Language": "zh-CN,zh;q=0.9",
        "Upgrade-Insecure-Requests": "1",
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/63.0.3239.26 Safari/537.36 Core/1.63.6756.400 QQBrowser/10.2.2457.400",
    }

    def process_request(self, request, spider):
        request.headers.setdefault('Accept', self.headers["Accept"])
        request.headers.setdefault('Accept-Encoding', self.headers["Accept-Encoding"])
        request.headers.setdefault('Accept-Language', self.headers["Accept-Language"])
        request.headers.setdefault('Upgrade-Insecure-Requests', self.headers["Upgrade-Insecure-Requests"])
        request.headers.setdefault('User-Agent', self.headers["User-Agent"])


class RandomUserAgentPc(object):

    def process_request(self, request, spider):
        import user_agent
        ua = user_agent.generate_user_agent(os="win", device_type=["desktop"])
        request.headers.setdefault('User-Agent', ua)


class RandomUserAgentMobile(object):

    def process_request(self, request, spider):
        import user_agent
        ua = user_agent.generate_user_agent(os="win", device_type=["smartphone"])
        request.headers.setdefault('User-Agent', ua)


class RandomUserAgentWechat(object):
    userAgents = {
        'weixin': [
            # weixin pc for windows
            'Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.95 Safari/537.36 MicroMessenger/6.5.2.501 NetType/WIFI WindowsWechat'
        ]
    }

    def process_request(self, request, spider):
        user_agent = random.choice(self.userAgents['weixin'])
        if user_agent:
            request.headers.setdefault('User-Agent', user_agent)
        return


class HeaderAcceptAll(object):
    def process_request(self, request, spider):
        request.headers.setdefault('Accept', "*/*")


class HeaderAcceptJson(object):

    def process_request(self, request, spider):
        request.headers.setdefault('Accept', "application/json, text/javascript, */*; q=0.01")
        request.headers.setdefault("X-Requested-With", "XMLHttpRequest")


class HeaderAcceptImg(object):

    def process_request(self, request, spider):
        request.headers.setdefault('Accept', "image/webp,image/apng,image/*,*/*;q=0.8")


class HeaderAcceptHtml(object):

    def process_request(self, request, spider):
        request.headers.setdefault('Accept', "text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8")


class AutoHomeHeader(object):
    headers = {
        "accept": "application/json, text/javascript, */*; q=0.01",
        "accept-encoding": "gzip, deflate, br",
        "accept-language": "zh-CN,zh;q=0.9",
        "user-agent": "Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/63.0.3239.26 Safari/537.36 Core/1.63.6726.400 QQBrowser/10.2.2265.400",
        "x-requested-with": "XMLHttpRequest"
    }

    def process_request(self, request, spider):
        request.headers.setdefault('User-Agent', self.headers["User-Agent"])



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time     : 2018/8/14 14:18
# @Author   : Peter
# @Site       : Model基类
# @File        : BaseModel.py
# @Software: PyCharm
from sqlalchemy import func, or_


class BaseModel:
    # TODO: pk = "id"

    # 更新model
    @staticmethod
    def merge_model(model, session, commit=True):
        session.merge(model)
        if commit:
            session.commit()

    # 添加model
    @staticmethod
    def add_model(model, session, commit=True):
        session.add(model)
        if commit:
            session.commit()

    # query
    @staticmethod
    def query(sql, session, *args, **kwargs):
        return session.execute(sql)

    # 通过id查询
    @classmethod
    def get(cls, _id, session):
        return session.query(cls).get(_id)

    # 查询所有
    @classmethod
    def get_all(cls, session):
        return session.query(cls).all()

    # 查询所有
    @classmethod
    def get_all_by_condition(cls, cond, session, relation="and", **kw):
        condition = list()
        for k, v in dict(cond).items():
            condition += [getattr(cls, k) == v]
        if relation == "and":
            return session.query(cls).filter(*condition).order_by("id").all()
        elif relation == "or":
            return session.query(cls).filter(or_(*condition)).order_by("id").all()
        else:
            return session.query(cls).all()

    # 查询所有id
    @classmethod
    def get_all_ids(cls, session):
        return session.query(cls.id).all()

    # 根据名字查找
    @classmethod
    def get_by_name(cls, name, session):
        return cls.getByKV("name", name, session)
        # return session.query(cls).filter(cls.name == name).all()

    # 从偏移量查找
    @classmethod
    def get_by_from_id(cls, from_id, session, **kw):
        if kw.get("where"):
            condition = list()
            for k, v in dict(kw.get("where")).items():
                condition += [getattr(cls, k) == v]
            if condition:
                return session.query(cls).filter(cls.id > from_id).filter(*condition).limit(kw.get("limit", 10)).all()
        return session.query(cls).filter(cls.id > from_id).limit(kw.get("limit", 10)).all()

    # 从偏移量查找，对ID取模
    # SELECT * FROM table_name WHERE id >{from_id} AND id % {mod} = {left}
    @classmethod
    def get_by_from_id_and_mod(cls, from_id, mod, left, session, **kw):
        if kw.get("where"):
            condition = list()
            for k, v in dict(kw.get("where")).items():
                condition += [getattr(cls, k) == v]
            if condition:
                return session.query(cls).filter(cls.id > from_id, cls.id % mod == left).filter(*condition).limit(kw.get("limit", 10)).all()
        return session.query(cls).filter(cls.id > from_id, cls.id % mod == left).limit(kw.get("limit", 10)).all()

    # 从偏移量查找部分字段，对ID取
    @classmethod
    def get_colums_by_from_id_and_mod(cls, Colums, from_id, mod, left, session, **kw):
        cls_colum = []
        for Colum in Colums:
            cls_colum.append(getattr(cls, Colum))
        return session.query(tuple(cls_colum)).filter(cls.id > from_id, cls.id % mod == left).limit(kw.get("limit", 10)).all()

    # 更新id
    @classmethod
    def update_id(cls, _id, to_id, session):
        res = session.execute("UPDATE " + str(cls.__tablename__) + " set id = " + str(to_id) + " WHERE id = " + str(_id) + " LIMIT 1")
        session.commit()
        return res

    # 更新字段
    @classmethod
    def update_kv(cls, _id, k, v, session):
        res = session.execute("UPDATE " + str(cls.__tablename__) + " set " + str(k) + " = '" + str(v) + "' WHERE id = '" + str(_id) + "' LIMIT 1")
        session.commit()
        return res

    # 更新字段
    @classmethod
    def update_kvby_condition(cls, cond_k, cond_v, value_k, value_v, session, limit=1):
        res = session.execute("UPDATE " + str(cls.__tablename__) + " set " + str(value_k) + " = '" + str(value_v) + "' WHERE " + cond_k + " = " + str(cond_v) + " LIMIT " + str(limit))
        session.commit()
        return res

    # 根据字段值获取ID
    @classmethod
    def get_id_by_kv(cls, k, v, session, **kw):
        return session.query(cls.id).filter(getattr(cls, k) == v).order_by("id").limit(kw.get("limit", 1)).all()

    # 根据多个字段值获取ID
    @classmethod
    def get_id_by_condition(cls, d, session, **kw):
        condition = list()
        for k, v in dict(d).items():
            condition += [getattr(cls, k) == v]
        return session.query(cls.id).filter(*condition).order_by("id").limit(kw.get("limit", 1)).all()

    # 根据字段值获取信息
    @classmethod
    def get_by_kv(cls, k, v, session, **kw):
        return session.query(cls).filter(getattr(cls, k) == v).order_by("id").limit(kw.get("limit", 10)).all()

    # 根据字段值获取信息
    @classmethod
    def get_by_condition(cls, d, session, relation="and", **kw):
        condition = list()
        for k, v in dict(d).items():
            condition += [getattr(cls, k) == v]
        if relation == "and":
            return session.query(cls).filter(*condition).order_by("id").limit(kw.get("limit", 10)).all()
        elif relation == "or":
            return session.query(cls).filter(or_(*condition)).order_by("id").limit(kw.get("limit", 10)).all()
        else:
            return None

    # 查询总条数
    @classmethod
    def get_count(cls, session):
        return session.query(func.count(cls.id)).scalar()

    # 获取TopN
    @classmethod
    def get_top_n(cls, order, session, **kwargs):
        return session.query(cls).order_by(order).limit(kwargs.get("limit", 10)).all()

    # TODO:Test
    @classmethod
    def get_k_region(cls, k, start_v, end_v, session, **kwargs):
        return session.query(cls).filter(getattr(cls, k) >= start_v, getattr(cls, k) < end_v).order_by(kwargs.get("order", "id")).limit(kwargs.get("limit", 10)).all()

    # ++
    @classmethod
    def increase_kv_by_id(cls, id_, k, session, **kwargs):
        res = session.query(cls).filter(cls.id == id_).update({
            getattr(cls, k): getattr(cls, k) + kwargs.get("incr", 1)
        })
        session.commit()
        return res

    # concat
    @classmethod
    def concat_kv_by_id(cls, id_, k, v, session, **kwargs):
        res = session.query(cls).filter(cls.id == id_).update({
            getattr(cls, k): func.concat(getattr(cls, k), v)
        })
        session.commit()
        return res

    # concat  UPDATE tb k_value = concat(k1,k2)
    @classmethod
    def concat_kk_2_k_by_id(cls, id_, k1, k2, k_value, session, **kwargs):
        res = session.query(cls).filter(cls.id == id_).update({
            getattr(cls, k_value): func.concat(getattr(cls, k1), func.concat(getattr(cls, k2)))
        })
        session.commit()
        return res

    # concat UPDATE tb k_value = concat(k,v)
    @classmethod
    def concat_kv_2_k_by_id(cls, id_, k, v, k_value, session, **kwargs):
        res = session.query(cls).filter(cls.id == id_).update({
            getattr(cls, k_value): func.concat(getattr(cls, k), v)
        })
        session.commit()
        return res


def create_init_function(cls):
    import types

    print("""def __init__(self, *arg, **kw):""")
    for k in dir(cls):
        if not (str(k).startswith("_") or isinstance(getattr(cls, k), types.FunctionType)):
            print("""    self.{attr} = kw.get("{attr}")""".format(attr=k))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time     : 2019/1/3 10:20
# @Email     : billsteve@126.com
# @Des       : 热点
# @File        : HotwordModel
# @Software: PyCharm
from sqlalchemy import Column, Date, String
from sqlalchemy.dialects.mysql import INTEGER, TINYINT
from sqlalchemy.ext.declarative import declarative_base
import XX.Model.SqlAlchemy.BaseModel as BaseModel

Base = declarative_base()
metadata = Base.metadata


class HotwordModel(Base, BaseModel.BaseModel):
    __tablename__ = 'hotword'

    id = Column(INTEGER(11), primary_key=True)
    word = Column(String(180))
    day = Column(Date)
    is_del = Column(TINYINT(1))
    update_ts = Column(INTEGER(11))
    create_ts = Column(INTEGER(11))

    def __init__(self, *arg, **kw):
        self.create_ts = kw.get("create_ts", None)
        self.day = kw.get("day", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.metadata = kw.get("metadata", None)
        self.update_ts = kw.get("update_ts", None)
        self.word = kw.get("word", None)


if __name__ == '__main__':
    BaseModel.createInitFunction(HotwordModel)



#!/usr/bin/python3
# -*- coding:utf-8 -*-
# @Time       : 2019/1/5 23:37
# @Author    : Bill Steve
# @Email      : billsteve@126.com
# @File         : Article.py
# @Des         : 
# @Software : PyCharm
from sqlalchemy import Column, DateTime, String, text
from sqlalchemy.dialects.mysql import INTEGER, TINYINT
from sqlalchemy.ext.declarative import declarative_base
import XX.Model.SqlAlchemy.BaseModel as BM

Base = declarative_base()
metadata = Base.metadata


class ArticleModel(Base, BM.BaseModel):
    __tablename__ = 'article'

    id = Column(INTEGER(11), primary_key=True)
    title = Column(String(300), server_default=text("''"))
    article_url = Column(String(300), server_default=text("''"))
    cover_url = Column(String(200), server_default=text("''"))
    description = Column(String(200), server_default=text("''"))
    publish_time = Column(DateTime)
    wx_id = Column(INTEGER(11), server_default=text("'0'"))
    read_count = Column(INTEGER(11), server_default=text("'0'"))
    like_count = Column(INTEGER(11), server_default=text("'0'"))
    comment_count = Column(INTEGER(11), server_default=text("'0'"))
    weixin_url = Column(String(300), server_default=text("''"))
    read_more_url = Column(String(300), server_default=text("''"))
    msg_index = Column(INTEGER(11), server_default=text("'0'"))
    copyright_stat = Column(INTEGER(1), server_default=text("'0'"))
    qunfa_id = Column(INTEGER(30), server_default=text("'0'"))
    type = Column(INTEGER(11), server_default=text("'0'"))
    is_del = Column(TINYINT(1))
    update_ts = Column(INTEGER(11))
    create_ts = Column(INTEGER(11))

    def __init__(self, *arg, **kw):
        self.article_url = kw.get("article_url", None)
        self.comment_count = kw.get("comment_count", None)
        self.copyright_stat = kw.get("copyright_stat", None)
        self.cover_url = kw.get("cover_url", None)
        self.create_ts = kw.get("create_ts", None)
        self.description = kw.get("description", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.like_count = kw.get("like_count", None)
        self.metadata = kw.get("metadata", None)
        self.msg_index = kw.get("msg_index", None)
        self.publish_time = kw.get("publish_time", None)
        self.qunfa_id = kw.get("qunfa_id", None)
        self.read_count = kw.get("read_count", None)
        self.read_more_url = kw.get("read_more_url", None)
        self.title = kw.get("title", None)
        self.type = kw.get("type", None)
        self.update_ts = kw.get("update_ts", None)
        self.weixin_url = kw.get("weixin_url", None)
        self.wx_id = kw.get("wx_id", None)


if __name__ == '__main__':
    BM.createInitFunction(ArticleModel)



# coding:utf8

import re
from urllib.parse import unquote
import requests
import sys


def get_char(js):
    all_var = {}
    # 判断混淆 无参数 返回常量 函数
    if_else_no_args_return_constant_function_functions = []
    """
    function zX_() {
            function _z() {
                return '09';
            };
            if (_z() == '09,') {
                return 'zX_';
            } else {
                return _z();
            }
        }
    """
    constant_function_regex4 = re.compile("""
        function\s+\w+\(\)\s*\{\s*
            function\s+\w+\(\)\s*\{\s*
                return\s+[\'\"][^\'\"]+[\'\"];\s*
            \};\s*
            if\s*\(\w+\(\)\s*==\s*[\'\"][^\'\"]+[\'\"]\)\s*\{\s*
                return\s*[\'\"][^\'\"]+[\'\"];\s*
            \}\s*else\s*\{\s*
                return\s*\w+\(\);\s*
            \}\s*
        \}
        """,
                                          re.X)
    l = constant_function_regex4.findall(js)
    for i in l:
        function_name = re.search("""
        function\s+(\w+)\(\)\s*\{\s*
            function\s+\w+\(\)\s*\{\s*
                return\s+[\'\"]([^\'\"]+)[\'\"];\s*
            \};\s*
            if\s*\(\w+\(\)\s*==\s*[\'\"]([^\'\"]+)[\'\"]\)\s*\{\s*
                return\s*[\'\"]([^\'\"]+)[\'\"];\s*
            \}\s*else\s*\{\s*
                return\s*\w+\(\);\s*
            \}\s*
        \}
        """, i,
                                  re.X)
        if_else_no_args_return_constant_function_functions.append(
            function_name.groups())
        js = js.replace(i, "")
        # 替换全文
        a, b, c, d = function_name.groups()
        all_var["%s()" % a] = d if b == c else b

    # 判断混淆 无参数 返回函数 常量
    if_else_no_args_return_function_constant_functions = []
    """
    function wu_() {
            function _w() {
                return 'wu_';
            };
            if (_w() == 'wu__') {
                return _w();
            } else {
                return '5%';
            }
        }
    """
    constant_function_regex5 = re.compile("""
        function\s+\w+\(\)\s*\{\s*
            function\s+\w+\(\)\s*\{\s*
                return\s+[\'\"][^\'\"]+[\'\"];\s*
            \};\s*
            if\s*\(\w+\(\)\s*==\s*[\'\"][^\'\"]+[\'\"]\)\s*\{\s*
                return\s*\w+\(\);\s*
            \}\s*else\s*\{\s*
                return\s*[\'\"][^\'\"]+[\'\"];\s*
            \}\s*
        \}
        """,
                                          re.X)
    l = constant_function_regex5.findall(js)
    for i in l:
        function_name = re.search("""
        function\s+(\w+)\(\)\s*\{\s*
            function\s+\w+\(\)\s*\{\s*
                return\s+[\'\"]([^\'\"]+)[\'\"];\s*
            \};\s*
            if\s*\(\w+\(\)\s*==\s*[\'\"]([^\'\"]+)[\'\"]\)\s*\{\s*
                return\s*\w+\(\);\s*
            \}\s*else\s*\{\s*
                return\s*[\'\"]([^\'\"]+)[\'\"];\s*
            \}\s*
        \}
        """, i,
                                  re.X)
        if_else_no_args_return_function_constant_functions.append(
            function_name.groups())
        js = js.replace(i, "")
        # 替换全文
        a, b, c, d = function_name.groups()
        all_var["%s()" % a] = b if b == c else d

    # var 参数等于返回值函数
    var_args_equal_value_functions = []
    """
    var ZA_ = function(ZA__) {
            'return ZA_';
            return ZA__;
        };
    """
    constant_function_regex1 = re.compile(
        "var\s+[^=]+=\s*function\(\w+\)\{\s*[\'\"]return\s*\w+\s*[\'\"];\s*return\s+\w+;\s*\};")
    l = constant_function_regex1.findall(js)
    for i in l:
        function_name = re.search("var\s+([^=]+)", i).group(1)
        var_args_equal_value_functions.append(function_name)
        js = js.replace(i, "")
        # 替换全文
        a = function_name
        js = re.sub("%s\(([^\)]+)\)" % a, r"\1", js)

    # var 无参数 返回常量 函数
    var_no_args_return_constant_functions = []
    """
    var Qh_ = function() {
            'return Qh_';
            return ';';
        };
    """
    constant_function_regex2 = re.compile("""
            var\s+[^=]+=\s*function\(\)\{\s*
                [\'\"]return\s*\w+\s*[\'\"];\s*
                return\s+[\'\"][^\'\"]+[\'\"];\s*
                \};
            """,
                                          re.X)
    l = constant_function_regex2.findall(js)
    for i in l:
        function_name = re.search("""
            var\s+([^=]+)=\s*function\(\)\{\s*
                [\'\"]return\s*\w+\s*[\'\"];\s*
                return\s+[\'\"]([^\'\"]+)[\'\"];\s*
                \};
            """,
                                  i,
                                  re.X)
        var_no_args_return_constant_functions.append(function_name.groups())
        js = js.replace(i, "")
        # 替换全文
        a, b = function_name.groups()
        all_var["%s()" % a] = b

    # 无参数 返回常量 函数
    no_args_return_constant_functions = []
    """
    function ZP_() {
            'return ZP_';
            return 'E';
        }
    """
    constant_function_regex3 = re.compile("""
            function\s*\w+\(\)\s*\{\s*
                [\'\"]return\s*[^\'\"]+[\'\"];\s*
                return\s*[\'\"][^\'\"]+[\'\"];\s*
            \}\s*
        """,
                                          re.X)
    l = constant_function_regex3.findall(js)
    for i in l:
        function_name = re.search("""
            function\s*(\w+)\(\)\s*\{\s*
                [\'\"]return\s*[^\'\"]+[\'\"];\s*
                return\s*[\'\"]([^\'\"]+)[\'\"];\s*
            \}\s*
        """,
                                  i,
                                  re.X)
        no_args_return_constant_functions.append(function_name.groups())
        js = js.replace(i, "")
        # 替换全文
        a, b = function_name.groups()
        all_var["%s()" % a] = b

    # 无参数 返回常量 函数 中间无混淆代码
    no_args_return_constant_sample_functions = []
    """
    function do_() {
            return '';
        }
    """
    constant_function_regex3 = re.compile("""
            function\s*\w+\(\)\s*\{\s*
                return\s*[\'\"][^\'\"]*[\'\"];\s*
            \}\s*
        """,
                                          re.X)
    l = constant_function_regex3.findall(js)
    for i in l:
        function_name = re.search("""
            function\s*(\w+)\(\)\s*\{\s*
                return\s*[\'\"]([^\'\"]*)[\'\"];\s*
            \}\s*
        """,
                                  i,
                                  re.X)
        no_args_return_constant_sample_functions.append(function_name.groups())
        js = js.replace(i, "")
        # 替换全文
        a, b = function_name.groups()
        all_var["%s()" % a] = b

    # 字符串拼接时使无参常量函数
    """
    (function() {
                'return sZ_';
                return '1'
            })()
    """
    constant_function_regex6 = re.compile("""
            \(function\(\)\s*\{\s*
                [\'\"]return[^\'\"]+[\'\"];\s*
                return\s*[\'\"][^\'\"]*[\'\"];?
            \}\)\(\)
        """,
                                          re.X)
    l = constant_function_regex6.findall(js)
    for i in l:
        function_name = re.search("""
            \(function\(\)\s*\{\s*
                [\'\"]return[^\'\"]+[\'\"];\s*
                return\s*([\'\"][^\'\"]*[\'\"]);?
            \}\)\(\)
        """,
                                  i,
                                  re.X)
        js = js.replace(i, function_name.group(1))

    # 字符串拼接时使用返回参数的函数
    """
    (function(iU__) {
                'return iU_';
                return iU__;
            })('9F')
    """
    constant_function_regex6 = re.compile("""
            \(function\(\w+\)\s*\{\s*
                [\'\"]return[^\'\"]+[\'\"];\s*
                return\s*\w+;
            \}\)\([\'\"][^\'\"]*[\'\"]\)
        """,
                                          re.X)

    l = constant_function_regex6.findall(js)
    for i in l:
        function_name = re.search("""
            \(function\(\w+\)\s*\{\s*
                [\'\"]return[^\'\"]+[\'\"];\s*
                return\s*\w+;
            \}\)\(([\'\"][^\'\"]*[\'\"])\)
        """,
                                  i,
                                  re.X)
        js = js.replace(i, function_name.group(1))

    # 获取所有变量
    var_regex = "var\s+(\w+)=(.*?);\s"

    for var_name, var_value in re.findall(var_regex, js):
        var_value = var_value.strip("\'\"").strip()
        if "(" in var_value:
            var_value = ";"
        all_var[var_name] = var_value

    # 注释掉 此正则可能会把关键js语句删除掉
    # js = re.sub(var_regex, "", js)

    for var_name, var_value in all_var.items():
        js = js.replace(var_name, var_value)

    js = re.sub("[\s+']", "", js)

    # 寻找%E4%B8%AD%E5%80%92%E 密集区域
    string_region = re.findall("((?:%\w\w)+)", js)
    string_str = ""
    for string_ in string_region:
        if len(string_) > len(string_str):
            string_str = string_

    string = unquote(string_str)

    # 从 字符串密集区域后面开始寻找索引区域
    index_m = re.search("([\d,]+(;[\d,]+)+)", js[js.find(string_str) + len(string_str):])
    string_list = list(string)
    index_list = index_m.group(1).split(";")

    _word_list = []
    for word_index_list in index_list:
        _word = ""
        if "," in word_index_list:
            word_index_list = word_index_list.split(",")
            word_index_list = [int(x) for x in word_index_list]
        else:
            word_index_list = [int(word_index_list)]
        for word_index in word_index_list:
            _word += string_list[word_index]
        _word_list.append(_word)
    return _word_list


def get_complete_text_autohome(text):
    types = re.findall('hs_kw\d+_([^\'\"]+)', text)
    types = set(types)
    # js_list = re.findall("<script>(\(function[\s\S]+?)\(document\);</script>", text.encode("utf8"))
    js_list = re.findall("<script>(\(function[\s\S]+?)\(document\);</script>", text)
    type_charlist = {}
    for js in js_list:
        for _type in types:
            if _type in js:
                break
        # else:
        #     continue
        if not js:
            continue
        try:
            char_list = get_char(js)
        except Exception as e:
            continue
        type_charlist.update({_type: char_list})

    def char_replace(m):
        index = int(m.group(1))
        typ = m.group(2)
        char_list = type_charlist.get(typ, [])
        if not char_list:
            return m.group()
        char = char_list[index]
        return char

    text = re.sub("<span\s*class=[\'\"]hs_kw(\d+)_([^\'\"]+)[\'\"]></span>", char_replace, text)
    return text


# get html
def getRealHtml(html):
    if html:
        # html = get_complete_text_autohome(html.encode('utf-8'))
        html = get_complete_text_autohome(html)
        try:
            text = re.search("<div\s*class=[\'\"]tz-paragraph[^\'\"]*?[\'\"]>([\s\S]+?)</div>", html).group(1)
        except:
            try:
                text = re.search("<div\s*class=[\'\"]conttxt content[^\'\"]*?[\'\"]>([\s\S]+?)</div>", html).group(1)
            except:
                try:
                    text = re.search("<div\s*class=[\'\"]content conttxt[^\'\"]*?[\'\"]>([\s\S]+?)</div>", html).group(1)
                except:
                    try:
                        text = re.search("<div\s*class=[\'\"]conttxt[^\'\"]*?[\'\"]>([\s\S]+?)</div>", html).group(1)
                    except:
                        try:
                            text = re.search("<div\s*class=[\'\"]content[^\'\"]*?[\'\"]>([\s\S]+?)</div>", html).group(1)
                        except:
                            text = ""
        return text


if __name__ == "__main__":
    import sys

    html = open("D:\\1.html", "r").read().encode("utf-8")
    print(len(html))
    html = getRealHtml(html)
    open("D:\\res.log", "w").write(html)
    print("===")



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time     : 2018/10/12 16:04
import os

import XX.File.FileHelper as uf


class CommonHelper():
    @classmethod
    def get_spider_by_forum_id(cls, **kw):
        pass

    # 获取唯一URL
    @staticmethod
    def uniqueUrl(url):
        return url

    # 删除缓存文件
    @staticmethod
    def remove_cache_file(url, spider, root_path_cache, sc):
        url = CommonHelper.uniqueUrl(url)
        uf.FileHelper.remove_file(root_path_cache + spider + sc + uf.FileHelper.get_md5_name(url) + ".cache")

    # 获取所有的spider名字
    @staticmethod
    def get_spiders(path, rp):
        spiders = []
        fns = uf.FileHelper.get_file_list(path)
        for fp, fn in fns:
            if fn.endswith("Spider.py"):
                for line in open(fp + os.sep + fn, encoding="utf-8"):
                    if line.strip().startswith("name ="):
                        spider = line.strip().split("=")[1].strip()
                        if spider.find("+") >= 0:
                            spider = eval(spider)
                        spiders.append(spider.strip("'").strip('"'))
        return spiders


class ResponseHelper:
    @staticmethod
    def check_response(response):
        if 400 <= response.status < 600:
            if response.status == 429 or response.status == 407 or response.status == 402:
                print("==Proxy error=== Status_code is " + str(response.status), flush=True)
            return False
        else:
            return True



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time     : 2018/12/5 15:43
# @Email     : billsteve@126.com
# @Des       : HBASE帮助类
# @File        : HBaseHelper
# @Software: PyCharm
import time

from hbase import Hbase
from hbase.ttypes import *
from thrift.transport import TSocket

import XX.Encrypt.EncryptHelper as enc


class HBaseHelper:
    client = None

    def __init__(self, **kw):
        self.transport = TSocket.TSocket(kw.get("host", "localhost"), kw.get("port", 9090))
        self.transport.open()
        self.protocol = TBinaryProtocol.TBinaryProtocol(self.transport)
        self.client = Hbase.Client(self.protocol)

    def get_client(self, **kw):
        transport = TSocket.TSocket(kw.get("host", "localhost"), kw.get("port", 9090))
        transport.open()
        protocol = TBinaryProtocol.TBinaryProtocol(transport)
        self.client = Hbase.Client(protocol)
        return self.client

    def get_client_by_cfg(self, cfg):
        return self.get_client(**cfg)

    # 获取最近三天的新数据
    def get_crawl_cache_response(self, table_name, spider_name, url, expire_seconds=86400, client=None):
        self.client = client if client else self.client
        result = self.client.getRowWithColumns(table_name, spider_name + "_" + enc.Encrypt.md5(url), ["data:json"])
        if result:
            if time.time() - result[0].columns.get('data:json').timestamp // 1000 <= expire_seconds:
                return result[0].columns.get('data:json').value

    # 添加缓存数据
    def add_crawl_cache_response(self, project, spider_name, url, fc, value, client=None):
        self.client = client if client else self.client
        mutation = Mutation(column=fc, value=value)
        return self.client.mutateRow("crawl_cache_" + project, spider_name + "_" + enc.Encrypt.md5(url), [mutation])

    # 创建表
    def create_table(self, table_name, columns, client=None):
        self.client = client if client else self.client
        self.client.createTable(table_name, columns)

    # 获取表
    def get_tables(self, client=None):
        self.client = client if client else self.client
        return self.client.getTableNames()

    # 删除整行
    def del_row(self, table_name, row, client=None):
        self.client = client if client else self.client
        return self.client.deleteAllRow(table_name, row)

    # 删除列
    def del_row_columns(self, table_name, row, column, client=None):
        self.client = client if client else self.client
        self.client.deleteAll(table_name, row, column)

    # 遍历表
    def get_lists(self, table, start_row, columns, limit=10, client=None):
        self.client = client if client else self.client
        scan_id = self.client.scannerOpen(table, start_row, columns)
        return self.client.scannerGetList(scan_id, limit)

    # 添加列
    def add_row_column(self, table, row, fc, value, client=None):
        self.client = client if client else self.client
        mutation = Mutation(column=fc, value=value)
        return self.client.mutateRow(table, row, [mutation])


if __name__ == '__main__':
    hb = HBaseHelper(host="zhihan00")
    print(hb.get_tables())
    exit()
    columns = list()
    columns.append(ColumnDescriptor(name='source'))
    columns.append(ColumnDescriptor(name='data'))
    hb.create_table("crawl_zhihan", columns)
    exit()
    start_row = ""
    while 1:
        results = hb.get_lists("crawl_cache_zhihan", start_row, ["source"])
        if not results:
            print("All Over")
            break
        for result in results:
            startRow = result.row
            print(result.row, result.columns["source:url"].value)
        time.sleep(0.5)
        print("--")



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time     : 2018/8/16 16:30
# @Author   : Peter
# @Des       : 
# @File        : Forum
# @Software: PyCharm
from XX.Model.SqlAlchemy.BaseModel import BaseModel
from sqlalchemy import Column, Integer, String, text
from sqlalchemy.dialects.mysql.types import TINYINT
from sqlalchemy.ext.declarative import declarative_base

Base = declarative_base()
metadata = Base.metadata


class Forum(Base, BaseModel):
    __tablename__ = 'forum'

    id = Column(Integer, primary_key=True)
    name = Column(String(255))
    spider_name = Column(String(255))
    domain = Column(String(255))
    logo = Column(String(255))
    thread_count = Column(TINYINT(4), server_default=text("'1'"))
    is_del = Column(Integer)
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.id = kw.get("id", None)
        self.name = kw.get("name", None)
        self.spider_name = kw.get("spider_name", None)
        self.domain = kw.get("domain", None)
        self.logo = kw.get("logo", None)
        self.thread_count = kw.get("thread_count", None)
        self.is_del = kw.get("is_del", None)
        self.create_ts = kw.get("create_ts", None)
        self.update_ts = kw.get("update_ts", None)

    @staticmethod
    def getSpiderNameByForumId(_id, session):
        return session.query(Forum.spider_name).filter(Forum.id == _id).all()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time         : 2019/3/21 17:25
# @File           : SaaS
# @Des           : 
# @Email        : billsteve@126.com
from BaseModel.BaseModel import *
from sqlalchemy import Column, String, TIMESTAMP, Text, text, DateTime
from sqlalchemy.dialects.mysql import INTEGER, LONGTEXT, TINYINT
from sqlalchemy.ext.declarative import declarative_base

Base = declarative_base()
metadata = Base.metadata


class BaiduAdvertisement(Base, BaseModel):
    __tablename__ = 'baidu_advertisement'

    id = Column(INTEGER(11), primary_key=True)
    url = Column(String(255))
    real_url = Column(String(255))
    snapshot_url = Column(String(255))
    title = Column(String(255))
    is_del = Column(INTEGER(11), server_default=text("'0'"))
    create_ts = Column(INTEGER(11))
    update_ts = Column(TIMESTAMP, server_default=text("CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP"))

    def __init__(self, *arg, **kw):
        self.create_ts = kw.get("create_ts", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.metadata = kw.get("metadata", None)
        self.real_url = kw.get("real_url", None)
        self.snapshot_url = kw.get("snapshot_url", None)
        self.title = kw.get("title", None)
        self.update_ts = kw.get("update_ts", None)
        self.url = kw.get("url", None)


class BaiduSearchResult(Base, BaseModel):
    __tablename__ = 'wp_saas_baidu_search_result'

    id = Column(INTEGER(11), primary_key=True)
    platform = Column(String(255))
    keyword = Column(String(255))
    crawl_time = Column(INTEGER(11))
    url = Column(String(255))
    real_url = Column(String(255), unique=True)
    source_url = Column(String(255))
    title = Column(String(255))
    spider = Column(String(60))
    skip_url = Column(Text)
    snapshot_url = Column(Text)
    show_url = Column(Text)
    is_ad = Column(TINYINT(1))
    content = Column(String(255))
    is_del = Column(TINYINT(1))
    update_ts = Column(INTEGER(11))
    create_ts = Column(INTEGER(11))

    def __init__(self, *arg, **kw):
        self.content = kw.get("content", None)
        self.crawl_time = kw.get("crawl_time", None)
        self.create_ts = kw.get("create_ts", None)
        self.id = kw.get("id", None)
        self.is_ad = kw.get("is_ad", None)
        self.is_del = kw.get("is_del", None)
        self.keyword = kw.get("keyword", None)
        self.metadata = kw.get("metadata", None)
        self.platform = kw.get("platform", None)
        self.real_url = kw.get("real_url", None)
        self.show_url = kw.get("show_url", None)
        self.skip_url = kw.get("skip_url", None)
        self.snapshot_url = kw.get("snapshot_url", None)
        self.source_url = kw.get("source_url", None)
        self.spider = kw.get("spider", None)
        self.title = kw.get("title", None)
        self.update_ts = kw.get("update_ts", None)
        self.url = kw.get("url", None)


class Company(Base, BaseModel):
    __tablename__ = 'wp_saas_company'
    id = Column(INTEGER(11), primary_key=True)
    ADDR = Column(String(255, 'utf8mb4_unicode_ci'))
    ANADDR = Column(String(255, 'utf8mb4_unicode_ci'))
    ENTTYPE = Column(String(255, 'utf8mb4_unicode_ci'))
    ENTTYPENAME = Column(String(255, 'utf8mb4_unicode_ci'))
    HIGHLIGHTTITLE = Column(String(255, 'utf8mb4_unicode_ci'))
    INVOPT = Column(String(255, 'utf8mb4_unicode_ci'))
    JYFW = Column(Text(collation='utf8mb4_unicode_ci'))
    NBXH = Column(String(80, 'utf8mb4_unicode_ci'), index=True)
    PRIPID = Column(String(255, 'utf8mb4_unicode_ci'))
    QYBM = Column(String(255, 'utf8mb4_unicode_ci'))
    QYWZ = Column(String(255, 'utf8mb4_unicode_ci'))
    REGNO = Column(String(80, 'utf8mb4_unicode_ci'), index=True)
    REGSTATECODE = Column(String(255, 'utf8mb4_unicode_ci'))
    REGSTATE_CN = Column(String(255, 'utf8mb4_unicode_ci'))
    REGUNIT = Column(String(255, 'utf8mb4_unicode_ci'))
    REGUNITNAME = Column(String(255, 'utf8mb4_unicode_ci'))
    SQ = Column(String(255, 'utf8mb4_unicode_ci'))
    S_EXT_NODENUM = Column(String(255, 'utf8mb4_unicode_ci'))
    TEL = Column(String(255, 'utf8mb4_unicode_ci'))
    UBINDTYPE = Column(String(255, 'utf8mb4_unicode_ci'))
    UBINDTYPENAME = Column(String(255, 'utf8mb4_unicode_ci'))
    UNITCODE = Column(String(255, 'utf8mb4_unicode_ci'))
    UNITNAME = Column(String(255, 'utf8mb4_unicode_ci'))
    XZQHBM = Column(String(255, 'utf8mb4_unicode_ci'))
    reg_time = Column(DateTime)
    is_del = Column(INTEGER(11))
    update_ts = Column(INTEGER(11))
    create_ts = Column(INTEGER(11))

    def __init__(self, *arg, **kw):
        self.ADDR = kw.get("ADDR", None)
        self.ANADDR = kw.get("ANADDR", None)
        self.ENTTYPE = kw.get("ENTTYPE", None)
        self.ENTTYPENAME = kw.get("ENTTYPENAME", None)
        self.HIGHLIGHTTITLE = kw.get("HIGHLIGHTTITLE", None)
        self.INVOPT = kw.get("INVOPT", None)
        self.JYFW = kw.get("JYFW", None)
        self.NBXH = kw.get("NBXH", None)
        self.PRIPID = kw.get("PRIPID", None)
        self.QYBM = kw.get("QYBM", None)
        self.QYWZ = kw.get("QYWZ", None)
        self.REGNO = kw.get("REGNO", None)
        self.REGSTATECODE = kw.get("REGSTATECODE", None)
        self.REGSTATE_CN = kw.get("REGSTATE_CN", None)
        self.REGUNIT = kw.get("REGUNIT", None)
        self.REGUNITNAME = kw.get("REGUNITNAME", None)
        self.SQ = kw.get("SQ", None)
        self.S_EXT_NODENUM = kw.get("S_EXT_NODENUM", None)
        self.TEL = kw.get("TEL", None)
        self.UBINDTYPE = kw.get("UBINDTYPE", None)
        self.UBINDTYPENAME = kw.get("UBINDTYPENAME", None)
        self.UNITCODE = kw.get("UNITCODE", None)
        self.UNITNAME = kw.get("UNITNAME", None)
        self.XZQHBM = kw.get("XZQHBM", None)
        self.create_ts = kw.get("create_ts", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.metadata = kw.get("metadata", None)
        self.reg_time = kw.get("reg_time", None)
        self.update_ts = kw.get("update_ts", None)


class ItjuziCompany(Base, BaseModel):
    __tablename__ = 'itjuzi_company'

    id = Column(INTEGER(11), primary_key=True)
    name = Column(String(255))
    des = Column(String(255))
    logo = Column(String(255))
    web_id = Column(INTEGER(11))
    is_del = Column(TINYINT(255))
    create_ts = Column(INTEGER(11))
    update_ts = Column(TIMESTAMP, server_default=text("CURRENT_TIMESTAMP"))

    def __init__(self, *arg, **kw):
        self.create_ts = kw.get("create_ts", None)
        self.des = kw.get("des", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.logo = kw.get("logo", None)
        self.metadata = kw.get("metadata", None)
        self.name = kw.get("name", None)
        self.update_ts = kw.get("update_ts", None)
        self.web_id = kw.get("web_id", None)


class ItjuziNew(Base, BaseModel):
    __tablename__ = 'itjuzi_news'

    id = Column(INTEGER(11), primary_key=True)
    title = Column(String(255))
    url = Column(String(255))
    logo = Column(String(255))
    web_id = Column(INTEGER(11))
    is_del = Column(TINYINT(255))
    create_ts = Column(INTEGER(11))
    update_ts = Column(TIMESTAMP, server_default=text("CURRENT_TIMESTAMP"))

    def __init__(self, *arg, **kw):
        self.create_ts = kw.get("create_ts", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.logo = kw.get("logo", None)
        self.metadata = kw.get("metadata", None)
        self.title = kw.get("title", None)
        self.update_ts = kw.get("update_ts", None)
        self.url = kw.get("url", None)
        self.web_id = kw.get("web_id", None)


class Url(Base, BaseModel):
    __tablename__ = 'wp_saas_url'

    id = Column(INTEGER(11), primary_key=True)
    domain = Column(String(255), index=True)
    url = Column(String(255), index=True)
    name = Column(String(255), index=True)
    level = Column(INTEGER(11))
    p_id = Column(INTEGER(11))
    content = Column(Text)
    title = Column(Text)
    description = Column(Text)
    keywords = Column(Text)
    is_del = Column(TINYINT(1))
    update_ts = Column(INTEGER(11))
    create_ts = Column(INTEGER(11))

    def __init__(self, *arg, **kw):
        self.content = kw.get("content", None)
        self.create_ts = kw.get("create_ts", None)
        self.description = kw.get("description", None)
        self.domain = kw.get("domain", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.keywords = kw.get("keywords", None)
        self.level = kw.get("level", None)
        self.metadata = kw.get("metadata", None)
        self.name = kw.get("name", None)
        self.p_id = kw.get("p_id", None)
        self.title = kw.get("title", None)
        self.update_ts = kw.get("update_ts", None)
        self.url = kw.get("url", None)


class Keyword(Base, BaseModel):
    __tablename__ = 'wp_saas_keywords'

    id = Column(INTEGER(11), primary_key=True)
    words = Column(String(192), nullable=False, unique=True)
    source = Column(INTEGER(1))
    flag = Column(INTEGER(1))
    update_ts = Column(TIMESTAMP, nullable=False, server_default=text("CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP"))
    create_ts = Column(TIMESTAMP, nullable=False, server_default=text("CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP"))

    def __init__(self, *arg, **kw):
        self.create_ts = kw.get("create_ts", None)
        self.flag = kw.get("flag", None)
        self.id = kw.get("id", None)
        self.metadata = kw.get("metadata", None)
        self.source = kw.get("source", None)
        self.update_ts = kw.get("update_ts", None)
        self.words = kw.get("words", None)


class NewsSearch(Base, BaseModel):
    __tablename__ = 'news_search'

    id = Column(INTEGER(11), primary_key=True)
    source_url = Column(String(255))
    url = Column(String(255))
    title = Column(String(255))
    top_image = Column(String(255))
    meta_img = Column(String(255))
    movies = Column(LONGTEXT)
    text = Column(String(255))
    keywords = Column(LONGTEXT)
    meta_keywords = Column(LONGTEXT)
    tags = Column(LONGTEXT)
    authors = Column(LONGTEXT)
    publish_date = Column(String(255))
    summary = Column(String(255))
    is_parsed = Column(String(255))
    download_state = Column(INTEGER(11))
    download_exception_msg = Column(String(255))
    meta_description = Column(String(255))
    meta_lang = Column(String(255))
    meta_favicon = Column(String(255))
    meta_data = Column(LONGTEXT)
    canonical_link = Column(String(255))
    additional_data = Column(LONGTEXT)
    link_hash = Column(String(255))
    is_del = Column(INTEGER(11))
    create_ts = Column(INTEGER(11))
    update_ts = Column(TIMESTAMP)

    def __init__(self, *arg, **kw):
        self.additional_data = kw.get("additional_data", None)
        self.authors = kw.get("authors", None)
        self.canonical_link = kw.get("canonical_link", None)
        self.create_ts = kw.get("create_ts", None)
        self.download_exception_msg = kw.get("download_exception_msg", None)
        self.download_state = kw.get("download_state", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.is_parsed = kw.get("is_parsed", None)
        self.keywords = kw.get("keywords", None)
        self.link_hash = kw.get("link_hash", None)
        self.meta_data = kw.get("meta_data", None)
        self.meta_description = kw.get("meta_description", None)
        self.meta_favicon = kw.get("meta_favicon", None)
        self.meta_img = kw.get("meta_img", None)
        self.meta_keywords = kw.get("meta_keywords", None)
        self.meta_lang = kw.get("meta_lang", None)
        self.metadata = kw.get("metadata", None)
        self.movies = kw.get("movies", None)
        self.publish_date = kw.get("publish_date", None)
        self.source_url = kw.get("source_url", None)
        self.summary = kw.get("summary", None)
        self.tags = kw.get("tags", None)
        self.text = kw.get("text", None)
        self.title = kw.get("title", None)
        self.top_image = kw.get("top_image", None)
        self.update_ts = kw.get("update_ts", None)
        self.url = kw.get("url", None)


class Product(Base, BaseModel):
    __tablename__ = 'wp_saas_product'

    id = Column(INTEGER(11), primary_key=True)
    url_id = Column(INTEGER(11), index=True)
    name = Column(String(255), index=True)
    p_id = Column(INTEGER(11))
    logo = Column(String(255))
    intro = Column(LONGTEXT)
    company_id = Column(INTEGER(11))
    is_del = Column(TINYINT(1))
    update_ts = Column(INTEGER(11))
    create_ts = Column(INTEGER(11))

    def __init__(self, *arg, **kw):
        self.create_ts = kw.get("create_ts", None)
        self.company_id = kw.get("company_id", None)
        self.id = kw.get("id", None)
        self.intro = kw.get("intro", None)
        self.is_del = kw.get("is_del", None)
        self.logo = kw.get("logo", None)
        self.metadata = kw.get("metadata", None)
        self.name = kw.get("name", None)
        self.p_id = kw.get("p_id", None)
        self.update_ts = kw.get("update_ts", None)
        self.url_id = kw.get("url_id", None)


class ProductSearch(Base, BaseModel):
    __tablename__ = 'product_search'

    id = Column(INTEGER(11), primary_key=True)
    source_url = Column(String(255))
    url = Column(String(255))
    title = Column(String(255))
    top_image = Column(String(255))
    meta_img = Column(String(255))
    movies = Column(LONGTEXT)
    text = Column(String(255))
    keywords = Column(LONGTEXT)
    meta_keywords = Column(LONGTEXT)
    tags = Column(LONGTEXT)
    authors = Column(LONGTEXT)
    publish_date = Column(String(255))
    summary = Column(String(255))
    is_parsed = Column(String(255))
    download_state = Column(INTEGER(11))
    download_exception_msg = Column(String(255))
    meta_description = Column(String(255))
    meta_lang = Column(String(255))
    meta_favicon = Column(String(255))
    meta_data = Column(LONGTEXT)
    canonical_link = Column(String(255))
    additional_data = Column(LONGTEXT)
    link_hash = Column(String(255))
    is_del = Column(INTEGER(11))
    create_ts = Column(INTEGER(11))
    update_ts = Column(TIMESTAMP)

    def __init__(self, *arg, **kw):
        self.additional_data = kw.get("additional_data", None)
        self.authors = kw.get("authors", None)
        self.canonical_link = kw.get("canonical_link", None)
        self.create_ts = kw.get("create_ts", None)
        self.download_exception_msg = kw.get("download_exception_msg", None)
        self.download_state = kw.get("download_state", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.is_parsed = kw.get("is_parsed", None)
        self.keywords = kw.get("keywords", None)
        self.link_hash = kw.get("link_hash", None)
        self.meta_data = kw.get("meta_data", None)
        self.meta_description = kw.get("meta_description", None)
        self.meta_favicon = kw.get("meta_favicon", None)
        self.meta_img = kw.get("meta_img", None)
        self.meta_keywords = kw.get("meta_keywords", None)
        self.meta_lang = kw.get("meta_lang", None)
        self.metadata = kw.get("metadata", None)
        self.movies = kw.get("movies", None)
        self.publish_date = kw.get("publish_date", None)
        self.source_url = kw.get("source_url", None)
        self.summary = kw.get("summary", None)
        self.tags = kw.get("tags", None)
        self.text = kw.get("text", None)
        self.title = kw.get("title", None)
        self.top_image = kw.get("top_image", None)
        self.update_ts = kw.get("update_ts", None)
        self.url = kw.get("url", None)


class ProductType(Base, BaseModel):
    __tablename__ = 'wp_saas_product_type'

    id = Column(INTEGER(11), primary_key=True)
    product_id = Column(INTEGER(11))
    type_id = Column(String(255))
    is_del = Column(TINYINT(1))
    update_ts = Column(INTEGER(11))
    create_ts = Column(INTEGER(11))

    def __init__(self, *arg, **kw):
        self.create_ts = kw.get("create_ts", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.metadata = kw.get("metadata", None)
        self.product_id = kw.get("product_id", None)
        self.type_id = kw.get("type_id", None)
        self.update_ts = kw.get("update_ts", None)


class Types(Base, BaseModel):
    __tablename__ = 'wp_saas_types'

    id = Column(INTEGER(11), primary_key=True)
    name = Column(String(255))
    p_id = Column(String(255))
    is_del = Column(TINYINT(1))
    update_ts = Column(INTEGER(11))
    create_ts = Column(INTEGER(11))

    def __init__(self, *arg, **kw):
        self.create_ts = kw.get("create_ts", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.metadata = kw.get("metadata", None)
        self.name = kw.get("name", None)
        self.p_id = kw.get("p_id", None)
        self.update_ts = kw.get("update_ts", None)


class ProductFromNews(Base, BaseModel):
    __tablename__ = 'wp_saas_product_from_news'

    id = Column(INTEGER(11), primary_key=True)
    news_id = Column(INTEGER(11), index=True)
    title = Column(String(255), index=True)
    products = Column(String(255))
    is_del = Column(TINYINT(1))
    update_ts = Column(INTEGER(11))
    create_ts = Column(INTEGER(11))

    def __init__(self, *arg, **kw):
        self.create_ts = kw.get("create_ts", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.metadata = kw.get("metadata", None)
        self.news_id = kw.get("news_id", None)
        self.products = kw.get("products", None)
        self.title = kw.get("title", None)
        self.update_ts = kw.get("update_ts", None)


if __name__ == '__main__':
    createInitFunction(BaiduAdvertisement)



# coding: utf-8
from XX.Model.SqlAlchemy.BaseModel import *
from sqlalchemy.ext.declarative import declarative_base

Base = declarative_base()
metadata = Base.metadata

# coding: utf-8
from sqlalchemy import Column, DateTime, Integer, String, TEXT, text
from sqlalchemy.dialects.mysql.types import TINYINT


class Beian(Base, BaseModel):
    __tablename__ = 'beian'

    id = Column(Integer, primary_key=True)
    url_id = Column(Integer)
    name = Column(String(255))
    url = Column(String(255))
    license = Column(String(255))
    icp_license = Column(String(255))
    entity = Column(String(255))
    web_type = Column(String(255))
    owner = Column(String(255))
    owner_city = Column(String(60))
    owner_id = Column(Integer)
    no = Column(String(255))
    org = Column(String(255))
    reg_time = Column(DateTime)
    art_licence = Column(String(55))
    is_del = Column(TINYINT(1))
    update_ts = Column(Integer)
    create_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.art_licence = kw.get("art_licence", None)
        self.create_ts = kw.get("create_ts", None)
        self.entity = kw.get("entity", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.license = kw.get("license", None)
        self.icp_license = kw.get("icp_license", None)
        self.metadata = kw.get("metadata", None)
        self.name = kw.get("name", None)
        self.no = kw.get("no", None)
        self.org = kw.get("org", None)
        self.owner = kw.get("owner", None)
        self.owner_city = kw.get("owner_city", None)
        self.owner_id = kw.get("owner_id", None)
        self.reg_time = kw.get("reg_time", None)
        self.update_ts = kw.get("update_ts", None)
        self.url = kw.get("url", None)
        self.url_id = kw.get("url_id", None)
        self.web_type = kw.get("web_type", None)


class Ip(Base, BaseModel):
    __tablename__ = 'ip'

    id = Column(Integer, primary_key=True)
    ip = Column(String(15), index=True)
    addr = Column(String(255))
    is_del = Column(TINYINT(1))
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.addr = kw.get("addr", None)
        self.create_ts = kw.get("create_ts", None)
        self.id = kw.get("id", None)
        self.ip = kw.get("ip", None)
        self.is_del = kw.get("is_del", None)
        self.metadata = kw.get("metadata", None)
        self.update_ts = kw.get("update_ts", None)


class IpSegment(Base, BaseModel):
    __tablename__ = 'ip_segment'

    id = Column(Integer, primary_key=True)
    ip_start = Column(String(255))
    ip_stop = Column(String(255))
    is_del = Column(TINYINT(1))
    create_ts = Column(Integer)
    update_ts = Column(Integer)


class Org(Base, BaseModel):
    __tablename__ = 'org'

    id = Column(Integer, primary_key=True)
    name = Column(String(255))
    is_del = Column(TINYINT(1))
    update_ts = Column(Integer)
    create_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.create_ts = kw.get("create_ts", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.metadata = kw.get("metadata", None)
        self.name = kw.get("name", None)
        self.update_ts = kw.get("update_ts", None)


class QueryType(Base, BaseModel):
    __tablename__ = 'query_types'

    id = Column(Integer, primary_key=True)
    name = Column(String(255))
    is_del = Column(TINYINT(1))
    update_ts = Column(Integer)
    create_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.create_ts = kw.get("create_ts", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.metadata = kw.get("metadata", None)
        self.name = kw.get("name", None)
        self.update_ts = kw.get("update_ts", None)


class Tag(Base, BaseModel):
    __tablename__ = 'tag'

    id = Column(Integer, primary_key=True)
    name = Column(String(60))
    is_del = Column(TINYINT(1))
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.create_ts = kw.get("create_ts", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.metadata = kw.get("metadata", None)
        self.name = kw.get("name", None)
        self.update_ts = kw.get("update_ts", None)


class Url(Base, BaseModel):
    __tablename__ = 'url'

    id = Column(Integer, primary_key=True)
    domain = Column(String(100))
    url = Column(String(255))
    name = Column(String(255))
    level = Column(Integer)
    p_id = Column(Integer)
    query_types = Column(String(255))
    is_del = Column(TINYINT(1))
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.create_ts = kw.get("create_ts", None)
        self.domain = kw.get("domain", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.level = kw.get("level", None)
        self.metadata = kw.get("metadata", None)
        self.name = kw.get("name", None)
        self.p_id = kw.get("p_id", None)
        self.query_types = kw.get("query_types", None)
        self.update_ts = kw.get("update_ts", None)
        self.url = kw.get("url", None)

    @staticmethod
    def geIdByDomainAndPid(domain, pid, sessoin):
        return sessoin.query(Url.id).filter(Url.domain == domain, Url.p_id == pid).order_by("id").all()


class UrlIp(Base, BaseModel):
    __tablename__ = 'url_ip'

    id = Column(Integer, primary_key=True)
    url_id = Column(Integer)
    ip_id = Column(Integer)
    ts = Column(DateTime)
    is_del = Column(TINYINT(1))
    update_ts = Column(Integer)
    create_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.create_ts = kw.get("create_ts", None)
        self.id = kw.get("id", None)
        self.ip_id = kw.get("ip_id", None)
        self.is_del = kw.get("is_del", None)
        self.metadata = kw.get("metadata", None)
        self.ts = kw.get("ts", None)
        self.update_ts = kw.get("update_ts", None)
        self.url_id = kw.get("url_id", None)

    @staticmethod
    def getIdByUrlIdIpId(url_id, ip_id, session):
        return session.query(UrlIp.id).filter(UrlIp.url_id == url_id, UrlIp.ip_id == ip_id).all()


class UrlTag(Base, BaseModel):
    __tablename__ = 'url_tag'
    id = Column(Integer, primary_key=True)
    url_id = Column(Integer, nullable=False)
    tag_id = Column(Integer, nullable=False)
    is_del = Column(TINYINT(1))
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.create_ts = kw.get("create_ts", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.metadata = kw.get("metadata", None)
        self.tag_id = kw.get("tag_id", None)
        self.update_ts = kw.get("update_ts", None)
        self.url_id = kw.get("url_id", None)


class OwnerInfo(Base, BaseModel):
    __tablename__ = 'owner_info'

    id = Column(Integer, primary_key=True)
    ADDR = Column(String(255))
    ANADDR = Column(String(255))
    ENTTYPE = Column(String(255))
    ENTTYPENAME = Column(String(255))
    HIGHLIGHTTITLE = Column(String(255))
    INVOPT = Column(String(255))
    JYFW = Column(TEXT)
    NBXH = Column(String(255))
    PRIPID = Column(String(255))
    QYBM = Column(String(255))
    QYWZ = Column(String(255))
    REGNO = Column(String(255))
    REGSTATECODE = Column(String(255))
    REGSTATE_CN = Column(String(255))
    REGUNIT = Column(String(255))
    REGUNITNAME = Column(String(255))
    SQ = Column(String(255))
    S_EXT_NODENUM = Column(String(255))
    TEL = Column(String(255))
    UBINDTYPE = Column(String(255))
    UBINDTYPENAME = Column(String(255))
    UNITCODE = Column(String(255))
    UNITNAME = Column(String(255))
    XZQHBM = Column(String(255))
    is_del = Column(Integer)
    update_ts = Column(Integer)
    create_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.ADDR = kw.get("ADDR", None)
        self.ANADDR = kw.get("ANADDR", None)
        self.ENTTYPE = kw.get("ENTTYPE", None)
        self.ENTTYPENAME = kw.get("ENTTYPENAME", None)
        self.HIGHLIGHTTITLE = kw.get("HIGHLIGHTTITLE", None)
        self.INVOPT = kw.get("INVOPT", None)
        self.JYFW = kw.get("JYFW", None)
        self.NBXH = kw.get("NBXH", None)
        self.PRIPID = kw.get("PRIPID", None)
        self.QYBM = kw.get("QYBM", None)
        self.QYWZ = kw.get("QYWZ", None)
        self.REGNO = kw.get("REGNO", None)
        self.REGSTATECODE = kw.get("REGSTATECODE", None)
        self.REGSTATE_CN = kw.get("REGSTATE_CN", None)
        self.REGUNIT = kw.get("REGUNIT", None)
        self.REGUNITNAME = kw.get("REGUNITNAME", None)
        self.SQ = kw.get("SQ", None)
        self.S_EXT_NODENUM = kw.get("S_EXT_NODENUM", None)
        self.TEL = kw.get("TEL", None)
        self.UBINDTYPE = kw.get("UBINDTYPE", None)
        self.UBINDTYPENAME = kw.get("UBINDTYPENAME", None)
        self.UNITCODE = kw.get("UNITCODE", None)
        self.UNITNAME = kw.get("UNITNAME", None)
        self.XZQHBM = kw.get("XZQHBM", None)
        self.create_ts = kw.get("create_ts", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.metadata = kw.get("metadata", None)
        self.update_ts = kw.get("update_ts", None)


if __name__ == '__main__':
    # createInitFunction(Beian)
    # createInitFunction(Ip)
    # createInitFunction(Org)
    # createInitFunction(Url)
    # createInitFunction(UrlIp)
    createInitFunction(QueryType)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time         : 2019/1/15 14:25
# @File           : NewsParse
# @Des           : 新闻解析
# @Email        : billsteve@126.com
from newspaper import Article


class NewsParse:
    def __init__(self, **kw):
        self.html = kw.get("html")
        self.url = kw.get("url")

    def getNewsItem(self, **kw):
        data = dict()

        html = self.html if self.html else kw.get("html")
        doc = Article(kw.get("url", "-"), language="zh")
        doc.download(input_html=html)
        doc.parse()
        data["url"] = doc.url
        data["title"] = doc.title
        data["content"] = doc.text
        data["date"] = str(doc.publish_date)
        return data


if __name__ == '__main__':
    from pprint import pprint

    # html = """</div>2018-09-18 13:35:03 &nbsp;<a href='http://look.huanqiu.com/article/2018-09/13041797.html' target='_blank'>环球网</a> &nbsp; &nbsp;<span class="chan_newsInfo_comment"><a href="#comment">参与评论(<em id="top_comment_number"></em>)人</a></span>"""
    html = open("a.html", encoding="utf-8").read()

    pprint(NewsParse.getNewsItem(NewsParse(), html=html))



#!/usr/bin/python3
# -*- coding:utf-8 -*-
# @Time        : 2018/7/24 14:03
# @Email       : billsteve@126.com
# @File          : Meihua.py
# @Software  : PyCharm


class MediaChannel(object):
    name = ""
    web_id = ""
    count = ""

    def __init__(self, *arg, **kw):
        self.name = kw.get("name", "")
        self.web_id = kw.get("web_id", "")
        self.count = kw.get("count", 0)


class MediaType(object):
    name = ""
    web_id = ""
    count = ""

    def __init__(self, *arg, **kw):
        self.name = kw.get("name", "")
        self.web_id = kw.get("web_id", "")
        self.count = kw.get("count", "")


class MediaInfo(object):
    name = ""
    web_id = ""
    price = ""
    circulation = ""

    def __init__(self, *arg, **kw):
        self.name = kw.get("name", "")
        self.web_id = kw.get("web_id", "")
        self.price = kw.get("price", "")
        self.circulation = kw.get("circulation", "")



# -*- coding: utf-8 -*-
import functools


def get_redis_conn_cfg(**kw):
    d = dict()
    d["host"] = kw.get("host", "localhost")
    d["pwd"] = kw.get("pwd", None)
    d["port"] = kw.get("port", 6379)
    d["db"] = kw.get("db", 0)
    d["decode_responses"] = kw.get("decode_responses", True)
    return d

ali_cfg = functools.partial(get_redis_conn_cfg, host="39.104.97.69", pwd="DRsXT5ZJ6Oi55LPQ", db=0)
ali2_cfg = functools.partial(get_redis_conn_cfg, host="39.104.57.130", pwd="DRsXT5ZJ6Oi55LPQ", db=0)
ubuntu_cfg = functools.partial(get_redis_conn_cfg, host="192.168.1.44", db=0)
local = functools.partial(get_redis_conn_cfg, host="localhost", db=0)
zhihan00 = functools.partial(get_redis_conn_cfg, host="zhihan00", db=0)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time     : 2018/10/18 14:58
# @Author   : Peter
# @Des       : 
# @File        : WeiboUser
# @Software: PyCharm
# coding: utf-8
from sqlalchemy import Column, Integer, String
from sqlalchemy.ext.declarative import declarative_base
from XX.Model.SqlAlchemy.BaseModel import BaseModel

Base = declarative_base()
metadata = Base.metadata


class WeiboUserModel(Base, BaseModel):
    __tablename__ = 'weibo_account'

    id = Column(Integer, primary_key=True)
    userName = Column(String(20))
    posts = Column(Integer)
    focus_num = Column(Integer)
    funs_num = Column(Integer)
    regTime = Column(String(20))
    addr = Column(String(20))
    signature = Column(String(300))
    tag_web = Column(String(255))
    tag_user = Column(String(255))
    intro = Column(String(255))
    uid = Column(Integer)
    fid = Column(Integer)
    authen_type = Column(Integer)
    gender = Column(Integer)
    level = Column(Integer)
    is_del = Column(Integer)
    update_ts = Column(Integer)
    containerid = Column(String(255))
    create_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.addr = kw.get("addr", None)
        self.authen_type = kw.get("authen_type", None)
        self.containerid = kw.get("containerid", None)
        self.create_ts = kw.get("create_ts", None)
        self.fid = kw.get("fid", None)
        self.focus_num = kw.get("focus_num", None)
        self.funs_num = kw.get("funs_num", None)
        self.gender = kw.get("gender", None)
        self.id = kw.get("id", None)
        self.intro = kw.get("intro", None)
        self.is_del = kw.get("is_del", None)
        self.level = kw.get("level", None)
        self.metadata = kw.get("metadata", None)
        self.posts = kw.get("posts", None)
        self.regTime = kw.get("regTime", None)
        self.signature = kw.get("signature", None)
        self.tag_user = kw.get("tag_user", None)
        self.tag_web = kw.get("tag_web", None)
        self.uid = kw.get("uid", None)
        self.update_ts = kw.get("update_ts", None)
        self.userName = kw.get("userName", None)


if __name__ == '__main__':
    BaseModel.createInitFunction(WeiboUserModel)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import urllib.parse as parse
from urllib.parse import urlparse

import tldextract
from tld import parse_tld, get_tld

import XX.Dict.DictHelper as h_dict
import XX.RegExp.RegExp as Re


class UrlHelper:

    # 检验是否是一个合法URL
    @staticmethod
    def check_url(url):
        if Re.RegExpHelper.is_url(url):
            return 1

    @staticmethod
    def check_domain(url):
        if Re.RegExpHelper.is_domain(url):
            return 1

    # 是否有参数列表
    @staticmethod
    def has_params(url):
        return

    # 获取域名
    @staticmethod
    def get_domain(url):
        url = UrlHelper.add_schema(url)
        return urlparse(url).hostname

    # 获取父域名
    @staticmethod
    def get_pdomain(url):
        try:
            val = tldextract.extract(url)
            if val.subdomain and val.subdomain != "www":
                if val.subdomain.count(".") > 0:
                    return f"""{".".join(val.subdomain.split('.')[1:])}.{val.domain}.{val.suffix}"""
                else:
                    return "{0}.{1}".format(val.domain, val.suffix)
            else:
                return None
        except Exception as e:
            return None

    # 获取协议
    @staticmethod
    def get_protocol(url):
        protocol = url.split(":")[0]
        if protocol.startswith("http"):
            return protocol

    # 删除参数:保留协议和基本网址
    @staticmethod
    def get_without_params(url):
        if not url:
            return ""
        url = url.split(UrlHelper.get_domain(url))[0] + UrlHelper.get_domain(url)
        return url if not url.endswith("/") else url[:-1]
        # return url.split("#")[0].split("?")[0]

    # 获取参数列表
    @staticmethod
    def get_params(url):
        res = {}
        try:
            values = url.split('?')[-1]
            for key_value in values.split('&'):
                try:
                    res[key_value.split('=')[0]] = key_value.split('=')[1]
                except:
                    pass
            return res
        except:
            print(" === URL: " + str(url))
            return {}

    # 添加参数
    @staticmethod
    def set_params(url, params):
        if not str(url).endswith("?"):
            url = url + "?"
        for k, v in dict(params).items():
            url = url + "&" + str(k) + "=" + str(v)
        url = str(url).replace("?&", "?")
        return url

    # 添加参数
    @staticmethod
    def add_params(url, d):
        params = UrlHelper.get_params(url.split("#")[0])
        main_url = UrlHelper.get_without_params(url)
        params = dict(params, **d)
        d = h_dict.DictHelper.sorted_dict_key(params)
        params_str = ""
        for k, v in d.items():
            params_str += "&" + str(k) + "=" + str(v)
        return main_url + "?" + params_str.lstrip("&")

    # url解码
    @staticmethod
    def url_decode(k):
        return parse.unquote(str(k))

    # URL编码
    @staticmethod
    def url_encode(k):
        return parse.quote(str(k))

    # 解析dict
    @staticmethod
    def parse_dict(item):
        for k in item:
            if isinstance(item[k], str):
                item[k] = UrlHelper.url_decode(item[k])
            elif isinstance(item[k], dict):
                item[k] = UrlHelper.parse_dict(item[k])
        return item

    # 从url中获取参数列表
    @staticmethod
    def format_url_to_dict(url):
        res = {}
        try:
            values = url.split('?')[-1]
            for key_value in values.split('&'):
                try:
                    res[key_value.split('=')[0]] = key_value.split('=')[1]
                except:
                    pass
            return res
        except Exception as e:
            raise e

    # 获取域名属于几级域名
    @staticmethod
    def get_url_level(url):
        url = UrlHelper.add_schema(url)
        if parse_tld(url)[2] == "" or parse_tld(url)[2] == "www":
            return 1
        elif parse_tld(url)[2]:
            return 2
        else:
            return 0

    @staticmethod
    def get_top_level_url(url):
        lurl = parse_tld(UrlHelper.add_schema(url))
        return lurl[1] + "." + lurl[0]

    # 域名的所有部分
    @staticmethod
    def get_main_url(url):
        url = UrlHelper.get_absolute_url(url)
        if url:
            lurl = parse_tld(url)
            if lurl[2] and len(lurl[2]):
                if lurl[2] == "www":
                    return lurl[1] + "." + lurl[0]
                else:
                    return lurl[2] + "." + lurl[1] + "." + lurl[0]
            elif lurl[1] and len(lurl[1]):
                return lurl[1] + "." + lurl[0]
            else:
                return lurl[0]

    @staticmethod
    def get_scheme(url):
        return get_tld(url, as_object=True).parsed_url.scheme

    @staticmethod
    def get_absolute_url(url, main_url=""):
        if url.startswith("#") or url.find("javascript") >= 0 or url.startswith("mailto"):
            return ""
        if url.startswith("/"):
            url = main_url + url
        if not url.startswith("http") or url.startswith("//"):
            url = "https://" + str(url).lstrip("//")
        return url

    @staticmethod
    def get_relative_url(url_source, url_new):
        if UrlHelper.get_absolute_url(url_new, url_source):
            return parse.urljoin(url_source, url_new)

    @staticmethod
    def add_schema(url, schema="http://"):
        return url if url.startswith("http://") or url.startswith("https://") else "http://" + url


if __name__ == '__main__':
    u = UrlHelper()
    d = u.get_scheme("https://2.3.1.ww.ymw.cn/")
    print(d)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time     : 2018/9/20 10:02
# @Author   : Peter
# @Des       : 
# @File        : Callback
# @Software: PyCharm


def msg(s, *arg, **kw):
    print("---" * 60)
    print("callback -------> {}".format(s))
    print("---" * 60)





# -*- coding:utf-8 -*-
import pymysql


def get_table_info(table, schema='', partition=True, mysql_cfg=None):
    cols = []
    create_head = """ create  external  table  if  not  exists  {0}.{1}(\n""".format(schema, table)
    if partition:
        create_tail = """\npartitioned  by(inc_day  string)\nrow  format  delimited  fields  terminated  by  '\\t' \n location  '/hivetable/{0}';""".format(
            table)
    else:
        create_tail = """\nrow  format  delimited  fields  terminated  by  '\\t' \nlocation  '/hivetable/{0}';""".format(
            table)
    connection = pymysql.connect(**mysql_cfg)
    try:
        # 获取一个游标
        with connection.cursor(cursor=pymysql.cursors.DictCursor)  as  cursor:
            sql = 'SHOW  FULL  FIELDS  FROM {0}'.format(table)
            for row in cursor:  # cursor.fetchall()
                cols.append(row['Field'])
                if 'bigint' in row['Type']:
                    row['Type'] = "bigint"
                elif 'int' in row['Type'] or 'tinyint' in row['Type'] or 'smallint' in row['Type'] or 'mediumint' in \
                        row['Type'] or 'integer' in row['Type']:
                    row['Type'] = "int"
                elif 'double' in row['Type'] or 'float' in row['Type'] or 'decimal' in row['Type']:
                    row['Type'] = "double"
                else:
                    row['Type'] = "string"
                create_head += row['Field'] + '  ' + row['Type'] + '  comment  \'' + row['Comment'] + '\' ,\n'
    finally:
        connection.close()
    create_str = create_head[:-2] + '\n' + ')' + create_tail
    return cols, create_str  # 返回字段列表与你建表语句

# cols, create_str = get_table_info("customer")
# print(create_str)



# -*- encoding:utf8 -*-
import json
import random
import traceback

import redis
import requests

import XX.Date.DatetimeHelper as Dt
import XX.HTTP.RequestsHelper as Rh
from XX.Debug import *


# 阿布云
def get_proxy(un="H76Z3LKO67NRN5QD", pwd="272305BABB9380E1", profession=False) -> dict:
    # 代理隧道验证信息
    proxyMeta = "http://%(user)s:%(pass)s@%(host)s:%(port)s" % {
        "host": "http-dyn.abuyun.com",
        "port": "9010" if profession else "9020",
        "user": un,
        "pass": pwd,
    }
    return {"http": proxyMeta, "https": proxyMeta}


def change_ip_abuyun(un="H76Z3LKO67NRN5QD", pwd="272305BABB9380E1"):
    # 代理隧道验证信息
    proxyMeta = "http://%(user)s:%(pass)s@%(host)s:%(port)s" % {
        "host": "http-dyn.abuyun.com",
        "port": "9010",
        "user": un,
        "pass": pwd,
    }
    url = "http://proxy.abuyun.com/switch-ip"
    pxy = {"http": proxyMeta, "https": proxyMeta}
    import requests
    res = requests.get(url, proxies=pxy)
    print("Change ip res is ", res.text)
    return 1


def get_random_proxy(r):
    ips = r.keys()
    while 1:
        if ips:
            ip = random.choice(ips)
            proxies = {
                "http": ip,
                "https": ip,
            }
            return proxies
        else:
            print("No more ip redis")
            time.sleep(1)
            continue


def add_tai_yang(redis_host="127.0.0.1", db=11):
    r = redis.Redis(redis_host, db=db)
    url = "http://http-api.taiyangruanjian.com/getip?num=1&type" \
          "=2&pro=&city=0&yys=0&port=11&pack=13604&ts=1&ys=0&cs=0&lb=1&sb=0&pb=4&mr=0&regions="
    while True:
        time.sleep(1)
        if r.dbsize() < 3:
            resp = Rh.RequestHelper.send_cache_request(url)
            if resp.status == 200:
                try:
                    json_data = json.loads(resp.text)
                    if json_data["code"] == 0:
                        ip = str(json_data["data"][0]["ip"]) + ":" + str(json_data["data"][0]["port"])
                        ets = int(Dt.str_to_ts(json_data["data"][0]["expire_time"]) - time.time() + 1)
                        d("OK " + json_data["data"][0]["expire_time"] + " ====== now + " + str(ets // 60), line1="===")
                        r.set(ip, 0, ex=ets)
                        time.sleep(1)
                except:
                    print("not json data" + resp.text)
                    traceback.print_exc()
            else:
                print("proxy return error" + str(resp.text))
        else:
            break
    return 1


def add_mivip_proxy(conn_redis, api=None, size=20):
    while 1:
        if conn_redis.dbsize() < size:
            try:
                req = requests.get(api, timeout=5)
                if req.status_code == 200:
                    json_data = json.loads(req.text)
                    ips = json_data.get("result")
                    if ips:
                        for ip in ips:
                            conn_redis.set(ip["ip:port"], 0, ip["time_avail"])
                            print("Add proxy" + str(ip["ip:port"]))
                    else:
                        print("No ip" + req.text)
                else:
                    print(req.status_code)
            except:
                traceback.print_exc()
        else:
            print("Too Much proxy")
        time.sleep(10)


def get_zhima_proxy(r) -> tuple:
    ips = r.keys()
    if ips:
        ip = random.choice(ips)
        proxies = {
            "http": ip,
            "https": ip,
        }
        return ip, proxies
    else:
        print("No more ip in zhima proxy(db11)")
        return None, None


def add_zhima(r, proxy_size=10, url="http://webapi.http.zhimacangku.com/getip?num=1&type=2&pro=&city=0&yys=0&port=11&pack=135714&ts=1&ys=0&cs=0&lb=1&sb=0&pb=4&mr=1&regions="):
    while True:
        time.sleep(1)
        if r.dbsize() < proxy_size:
            resp = Rh.RequestHelper.send_cache_request(url)
            if resp.status == 200:
                try:
                    json_data = json.loads(resp.text)
                    if json_data["code"] == 0:
                        ip = str(json_data["data"][0]["ip"]) + ":" + str(json_data["data"][0]["port"])
                        ets = int(Dt.str_to_ts(json_data["data"][0]["expire_time"]) - time.time() + 1)
                        d("OK " + json_data["data"][0]["expire_time"] + " ====== now + " + str(ets // 60), line1="===")
                        r.set(ip, 0, ex=ets)
                        time.sleep(1)
                    else:
                        print(json_data)
                except:
                    print("Not json data" + resp.text)
                    traceback.print_exc()
            else:
                print("proxy return error" + str(resp.text))
        else:
            print("Enough")
            time.sleep(3)


def test_ip(r):
    headers = {
        "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8",
        "Accept-Encoding": "gzip, deflate",
        "Accept-Language": "zh-CN,zh;q=0.9",
        "Connection": "keep-alive",
        "Upgrade-Insecure-Requests": "1",
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/63.0.3239.26 Safari/537.36 Core/1.63.5005.400 QQBrowser/10.0.923.400"
    }
    while 1:
        proxy = get_random_proxy(r)
        if proxy:
            urls = list()
            urls.append("https://www.baidu.com")
            urls.append("https://www.qq.com")
            for url in urls:
                try:
                    req = requests.get(url, proxies=proxy, timeout=5, headers=headers)
                    if req.status_code != 200:
                        # TODO：删除代理
                        pass
                    time.sleep(1)
                except:
                    print("time out" + url)
        else:
            p(" Wrong proxy", line="-----")


def get_proxy_by_ip(ip, port=80):
    proxies = {
        "http": f"{ip}:{port}",
        "https": f"{ip}:{port}",
    }
    return proxies


get_abuyun_proxy = get_proxy

if __name__ == '__main__':
    # 阿布云测试
    req = requests.get("https://www.baidu.com", proxies=get_abuyun_proxy("H4FJM3WZYGEP79ND", "6D8897ED95103EBC"))
    print(req.status_code)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import happybase


class HappyBaseHelper:
    connection = None
    table = None
    pool = None

    def __init__(self, **kw):
        if kw:
            self.connection = happybase.Connection(**kw)

    def get_connection_pool(self, size=128, **kw):
        self.pool = happybase.ConnectionPool(**kw, size=size)
        return self.pool

    def get_connection(self, **kwargs):
        if kwargs.get("host"):
            self.connection = happybase.Connection(**kwargs)
            return self.connection

    def get_table(self, table_name, conn=None, pool=None):
        self.connection = conn if conn else self.connection
        return self.connection.table(table_name)

    # 创建表
    def create_table(self, table_name, columns, conn=None):
        self.connection = conn if conn else self.connection
        return self.connection.create_table(table_name, columns)

    # 获取表
    def get_tables(self, conn=None):
        self.connection = conn if conn else self.connection
        return self.connection.tables()

    # 删除表
    def del_table(self, table_name, disable=False, conn=None):
        self.table = self.get_table(table_name, conn) if table_name else self.table
        return self.connection.delete_table(self.table, disable)

    # 获取行
    def get_row(self, row, conn=None, table_name=None):
        self.table = self.get_table(table_name, conn) if table_name else self.table
        return self.table.row(row)

    # 获取列表
    def get_rows(self, row, conn=None, table_name=None):
        self.table = self.get_table(table_name, conn) if table_name else self.table
        return self.table.row(row)

    # 删除行或列
    def del_row(self, row, columns=None, conn=None, table_name=None):
        self.table = self.get_table(table_name, conn) if table_name else self.table
        return self.table.delete(row, columns)

    # 添加行
    def add_row(self, row, data, timestamp=None, wal=True, conn=None, table_name=None):
        self.table = self.get_table(table_name, conn) if table_name else self.table
        return self.table.put(row, data, timestamp=None, wal=True)
